@@ -19,7 +19,7 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# $Id: GFClient.py 7104 2005-03-07 16:49:25Z johannes $
+# $Id: GFClient.py 7650 2005-06-24 13:21:47Z jamest $
 
 """
 Command line client startup file that parses args, imports the required UI,
@@ -44,8 +44,8 @@ try:
 
 except:
   REPORTS_SUPPORT = False
-  
-  
+
+
 # =============================================================================
 # GNU Enterprise Forms Client
 # =============================================================================
@@ -178,8 +178,8 @@ class GFClient (GClientApp):
     gDebug (4, "Parsing form definition")
     instance.addFormFromFile (formfile)
 
-    gDebug (4, "Parsing standard dialogs")
-    instance.addDialogs ()
+    #gDebug (4, "Parsing standard dialogs")
+    #instance.addDialogs ()
 
     gDebug (4, "Activating form")
     instance.activate ()
