@@ -762,7 +762,7 @@ class DateDisplayHandler(FieldDisplayHandler):
     if value in (None,""):
       return ""
     try:
-      return value.strftime(format)
+      return value.strftime (str (format))
     except AttributeError:
       return str(value)
 
