@@ -24,7 +24,7 @@
 #
 # NOTES:
 #
-# $Id: GFForm.py 7104 2005-03-07 16:49:25Z johannes $
+# $Id: GFForm.py 7824 2005-08-11 03:20:07Z jamest $
 
 import sys
 import string
@@ -139,7 +139,7 @@ class GFForm(GRootObj, GFObj, events.EventAware):
                               'messageBox': {'function':self.triggerMessageBox,
                                              'global': True
                                              },
-                              'commit':{'function':self.commit,
+                              'commit':{'function':self.triggerCommit,
                                         'global': True,
                                         },
                               'rollback':{'function':self.rollback,
@@ -148,6 +148,9 @@ class GFForm(GRootObj, GFObj, events.EventAware):
                               'close':{'function':self.triggerClose,
                                        'global': True,
                                        },
+                              'beep':{'function':self.triggerBeep,
+                                       'global': True,
+                                       },
                               'getFeature':{'function':self.triggerGetFeature,
                                             'global': True,
                                             },
@@ -253,13 +256,22 @@ class GFForm(GRootObj, GFObj, events.EventAware):
   #---------------------------------------------------------------------------
   def findAndChangeFocus(self, object):
     """
-    Find focus and change it to new entry.
-    @param: object
-    @return: None
+    Change the focus to the first focusable element of the given object.
+
+    The object passed can be a page or a block (in which case the first entry
+    on that page/block will be focused) or an entry (in which case exactly this
+    entry will be focused).
+
+    The focus will be set on GF and on UI layer.
+
+    @param: Object from the GF layer
     """
     entry = self.findFocus(object)
     if entry:
+      # Set focus on GF layer
       self.changeFocus(entry)
+      # Set focus on UI layer
+      self.dispatchEvent('gotoENTRY', object=entry, _form=self)
 
 
   #---------------------------------------------------------------------------
@@ -272,7 +284,7 @@ class GFForm(GRootObj, GFObj, events.EventAware):
     @param: object (page, block or entry) to find next focus for.
     @return: None or entry with next focus
     """
-
+    
     if object._type == 'GFField':
       gDebug (5, "GFField was passed to 'findFocus'.")
       try:
@@ -338,7 +350,7 @@ class GFForm(GRootObj, GFObj, events.EventAware):
 
     # cannot change focus to same entry
     if widget == self._currentEntry:
-      gDebug (5, "Widget is current entry %s" % widget)
+      gDebug (5, "Current entry did not change from %s" % widget)
       return
 
     cen = self._currentEntry is not None and self._currentEntry.name or '-'
@@ -481,12 +493,23 @@ class GFForm(GRootObj, GFObj, events.EventAware):
     Checks all block in the form whether they are saved (committed) or not.
     @return: boolean, True if all the blocks are committed.
     """
+
+    # Is the current entry changed?
+    # FIXME: should only cause the form to appear unsaved if the entry is bound
+    # to a field.
     if (self._currentEntry._type != 'GFButton' and \
         self._currentEntry._displayHandler.isPending()):
       return False
 
+    # Are there any not yet posted changes in any of the blocks?
     for block in self._logic._blockList:
-      if not block.isSaved():
+      if block.isPending():
+        return False
+
+    # Does a connection have any pending (already posted but not yet committed)
+    # changes?
+    for connection in (self.__getConnections ()).values ():
+      if connection.isPending ():
         return False
 
     return True
@@ -508,7 +531,7 @@ class GFForm(GRootObj, GFObj, events.EventAware):
         self.commit()
 
       for block in self._logic._blockList:
-        if not block.isSaved():
+        if block.isPending():
           message = _("Data not saved. Save changes or clear the form to "
                       "proceed.")
           return message
@@ -625,6 +648,7 @@ class GFForm(GRootObj, GFObj, events.EventAware):
       return _('Form is readonly')
     
     message = None
+    newBlock = None                     # block to jump to after commit
     self.dispatchEvent ('beginWAIT', _form = self)
 
     try:
@@ -639,7 +663,7 @@ class GFForm(GRootObj, GFObj, events.EventAware):
 
         except AbortRequest:
           gDebug (5, "Trigger form Pre-Commit threw a AbortRequest!")
-          return _("Form trigger returned error")
+          message = u_("Form trigger returned error")
 
 
         # Process the commit on all blocks
@@ -650,16 +674,26 @@ class GFForm(GRootObj, GFObj, events.EventAware):
 
           except AbortRequest:
             gDebug (5, "Trigger block Pre-Commit threw a AbortRequest!")
-            return _("Block trigger returned error")
+            message = u_("Block trigger returned error")
+            # jump to offending block
+            newBlock = block
+          except:
+            # jump to offending block
+            newBlock = block
+            raise
 
-        # Now do the real commit () on the backend connections (only once per
-        # connection, if multiple blocks are sharing the same connection)
-        for conn in self.__getConnections ().values ():
-          conn.commit ()
+        try:
+          # Now do the real commit () on the backend connections (only once per
+          # connection, if multiple blocks are sharing the same connection)
+          for conn in self.__getConnections ().values ():
+            conn.commit ()
 
-        # Make sure the block is in consistent state again
-        for block in self._logic._blockList:
-          block.finalizeCommit ()
+        finally:
+          # Make sure the block is in consistent state again; this has to be
+          # done in any case if the processCommit was successful, even if the
+          # connection commit failed - thus the "finally" here.
+          for block in self._logic._blockList:            
+            block.finalizeCommit ()
 
         # Execute Post-Commit-Trigger for each block
         for block in self._logic._blockList:
@@ -676,15 +710,15 @@ class GFForm(GRootObj, GFObj, events.EventAware):
         self.processTrigger ('Post-Commit')
 
       except DBError:
-        self.rollback (1)
         message = u_("Database commit error:\n%(exType)s\n%(exMessage)s") \
             % {'exType'   : sys.exc_info ()[0],
-               'exMessage': sys.exc_info ()[1]}
+               'exMessage': sys.exc_info ()[1]}               
 
     finally:
       # Make sure the current block still has the focus, even if an exception
       # occured during commit or in a trigger
-      self.findAndChangeFocus (self._currentBlock)
+      if newBlock is not None and newBlock != self._currentBlock:
+        self.findAndChangeFocus (newBlock)
       self.dispatchEvent ('endWAIT', _form = self)
 
     gLeave (4)
@@ -722,21 +756,22 @@ class GFForm(GRootObj, GFObj, events.EventAware):
 
   def __getConnections (self):
     """
-    This function creates a dictionary of all connections used by the form's
-    blocks, where the connection-name is the key and the connection instance is
+    This function creates a dictionary of all connections referenced by the form,
+    where the connection-name is the key and the connection instance is
     the value.
 
     @return: dictionary with all connections used by the form
     """
 
     result = {}
-
-    for block in self._logic._blockList:
-      dLink = block._dataSourceLink
-      if not result.has_key (dLink.connection) and \
-          dLink._dataObject._connection is not None:
-        result [dLink.connection] = dLink._dataObject._connection
-
+    for dLink in self._datasourceDictionary.values():
+      try:
+        if dLink._connection is not None:
+          result [dLink.connection] = dLink._connection
+      except AttributeError:
+        pass
+        
+    
     return result
 
 
@@ -924,7 +959,9 @@ class GFForm(GRootObj, GFObj, events.EventAware):
     @return: None
     """
     block = self._currentBlock
-    if not block: return
+    if not block:
+      gDebug(5,'No current block - cannot refresh UI')
+      return
 
     dispatchEvent = self.dispatchEvent
     if block.mode == 'query':
@@ -1123,6 +1160,27 @@ class GFForm(GRootObj, GFObj, events.EventAware):
   # functions exposed in the trigger namespace.
   #===========================================================================
 
+  #---------------------------------------------------------------------------
+  # trigger commits
+  #---------------------------------------------------------------------------
+  def triggerCommit(self):
+    """
+    Causes the form to commit
+    """  
+    event = events.Event('requestCOMMIT',_form=self)
+    self._instance.executeCommit(event)
+  
+  #---------------------------------------------------------------------------
+  # trigger beep
+  #---------------------------------------------------------------------------
+  def triggerBeep(self):
+    """
+    Tells the UI to beep (if possible)
+    
+    @return: None
+    """
+    self.dispatchEvent('formBEEP', _form=self)
+  
   #---------------------------------------------------------------------------
   # display a standard message box
   #---------------------------------------------------------------------------
@@ -1258,7 +1316,7 @@ class GFForm(GRootObj, GFObj, events.EventAware):
                           1,
                           parameters=parameters)
     instance.addFormFromFile(fileName)
-    instance.addDialogs ()
+    #instance.addDialogs ()
     instance.activate()
 
 
@@ -1269,7 +1327,8 @@ class GFForm(GRootObj, GFObj, events.EventAware):
     """
     Launches a new instance of GNUe-Reports, running a new report.
     @param reportFile: the name of the .grd file to be processed
-    @param parameters:
+    @param parameters: dictionary of parameters to be passed
+                        to the newly run report
     @param **params:
       These roughly correspond to the ./gnue-reports options
               destination
@@ -1277,7 +1336,6 @@ class GFForm(GRootObj, GFObj, events.EventAware):
               destinationOptions (dict)
               filter
               filterOptions (dict)
-              parameters (dict)
               sortoption
               includeStructuralComments
               omitGNUeXML
@@ -1302,12 +1360,12 @@ class GFForm(GRootObj, GFObj, events.EventAware):
     @param modal: whether the dialog should be modal or not
     @return: None
     """
-    if dialogName == '_about' and \
-      hasattr(self._instance._uiinstance, 'aboutBox'):
-      self._instance._uiinstance.aboutBox(parameters, self)
-    else:
-      self._instance.activateForm(dialogName, parameters, modal)
 
+    if dialogName == '_about':
+      self._instance._uiinstance.showAbout (**parameters)
+    else:      
+      self._instance.activateForm(dialogName, parameters, modal)    
+                                
 
   #---------------------------------------------------------------------------
   # Close this copy of gnue-forms
