@@ -19,7 +19,7 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# $Id: GFInstance.py 7104 2005-03-07 16:49:25Z johannes $
+# $Id: GFInstance.py 7811 2005-08-09 18:30:12Z reinhard $
 
 """
 GFInstance manages forms instances in a 1:N relationship. It sits between the
@@ -87,14 +87,6 @@ class GFInstance (events.EventAware):
                            # First, all events are passed to the focus widget
                            '__before__'          : self.__beforeEvent,
 
-                           # Datasource trigger events
-                           'preCommit'           : self.preCommit,
-                           'preUpdate'           : self.preUpdate,
-                           'preInsert'           : self.preInsert,
-                           'preDelete'           : self.preDelete,
-                           'onRecordTouched'     : self.onRecordTouched,
-                           'onQueryNewRecord'    : self.onQueryNewRecord,
-
                            # Focus-related events
                            'requestENTER'        : self.nextEntry,
                            'requestNEXTENTRY'    : self.nextEntry,
@@ -175,40 +167,40 @@ class GFInstance (events.EventAware):
   # Add the basic dialogs
   # ---------------------------------------------------------------------------
 
-  def addDialogs (self):
-    """
-    Loads the base dialogs into memory.
-
-    Base dialogs include items such as the jump to record
-    dialog and error dialogs.
-    """
-
-    # Import and register dialogs
-    basedir = os.path.dirname (sys.modules [self.__module__].__file__)
-    basedir = os.path.join (basedir, 'dialogs')
-
-    for dialogName in dircache.listdir (basedir):
-
-      if dialogName [0] == '_' or dialogName == '.svn':
-        continue
-
-      filename    = os.path.join (basedir, dialogName)
-      (name, ext) = os.path.splitext (dialogName)
-
-      if os.path.isfile (filename) and ext == '.py':
-        dialog = dyn_import ('gnue.forms.dialogs.%s' % name)
-
-      elif os.path.isdir (filename):
-        dialog = dyn_import ('gnue.forms.dialogs.%s' % dialogName)
-
-      else:
-        continue
-
-      try:
-        self.addFormFromBuffer (dialog.buildForm ())
-
-      except StandardError, mesg:
-        print "WARNING: Cannot build %s form \n%s" % (dialogName, mesg)
+#   def addDialogs (self):
+#     """
+#     Loads the base dialogs into memory.
+# 
+#     Base dialogs include items such as the jump to record
+#     dialog and error dialogs.
+#     """
+# 
+#     # Import and register dialogs
+#     basedir = os.path.dirname (sys.modules [self.__module__].__file__)
+#     basedir = os.path.join (basedir, 'dialogs')
+# 
+#     for dialogName in dircache.listdir (basedir):
+# 
+#       if dialogName [0] == '_' or dialogName == '.svn':
+#         continue
+# 
+#       filename    = os.path.join (basedir, dialogName)
+#       (name, ext) = os.path.splitext (dialogName)
+# 
+#       if os.path.isfile (filename) and ext == '.py':
+#         dialog = dyn_import ('gnue.forms.dialogs.%s' % name)
+# 
+#       elif os.path.isdir (filename):
+#         dialog = dyn_import ('gnue.forms.dialogs.%s' % dialogName)
+# 
+#       else:
+#         continue
+# 
+#       try:
+#         self.addFormFromBuffer (dialog.buildForm ())
+# 
+#       except StandardError, mesg:
+#         print "WARNING: Cannot build %s form \n%s" % (dialogName, mesg)
 
 
   # ---------------------------------------------------------------------------
@@ -291,7 +283,7 @@ class GFInstance (events.EventAware):
 
     for child in formTree._children [:]:
       if isinstance (child, GFForm):
-        child._parent = None
+        child.setParent (None)
         self._formsDictionary [child.name] = child
         formTree._children.remove (child)
 
@@ -306,18 +298,9 @@ class GFInstance (events.EventAware):
 
     # Initialize all the forms loaded into memory
     gDebug (4, "Initializing form objects")
-    try:
-      for formObject in self._formsDictionary.values ():
-        formObject.phaseInit ()
 
-    except Exceptions.ConnectError:
-      raise StartupError, \
-          u_("Unable to login to datasource: %s") % errors.getException () [2]
-
-    except Exceptions.ConnectionError:
-      raise StartupError, \
-          u_("Error while communicating with datasource: %s") \
-          % errors.getException () [2]
+    for formObject in self._formsDictionary.values ():
+      formObject.phaseInit ()
 
     gDebug (4, "Initializing user interface driver object")
     self._uiinstance.initialize ()
@@ -630,8 +613,6 @@ class GFInstance (events.EventAware):
       return
 
     event._form.nextBlock ()
-    self.dispatchEvent ('gotoENTRY', object = event._form._currentEntry,
-                        _form = event._form)
     self.updateStatus (event._form)
 
 
@@ -649,8 +630,6 @@ class GFInstance (events.EventAware):
       return
 
     event._form.previousBlock ()
-    self.dispatchEvent ('gotoENTRY', object = event._form._currentEntry,
-                        _form = event._form)
     self.updateStatus (event._form)
 
 
@@ -673,8 +652,6 @@ class GFInstance (events.EventAware):
       nextIndex = currentIndex + 1
 
     event._form.findAndChangeFocus (event._form._layout._pageList [nextIndex])
-    self.dispatchEvent ('gotoENTRY', object = event._form._currentEntry,
-                        _form = event._form)
     self.updateStatus (event._form)
 
 
@@ -693,9 +670,6 @@ class GFInstance (events.EventAware):
     pageList = event._form._layout._pageList
     currentIndex = pageList.index (event._form._currentPage)
     event._form.findAndChangeFocus (pageList [currentIndex - 1])
-
-    self.dispatchEvent ('gotoENTRY', object = event._form._currentEntry,
-                        _form = event._form)
     self.updateStatus (event._form)
 
   # ---------------------------------------------------------------------------
@@ -712,9 +686,6 @@ class GFInstance (events.EventAware):
 
     newpage = event._form._layout._pageList [event.data]
     event._form.findAndChangeFocus (newpage)
-    
-    self.dispatchEvent ('gotoENTRY', object = event._form._currentEntry,
-                       _form = event._form)
     self.updateStatus (event._form)
 
 
@@ -986,18 +957,13 @@ class GFInstance (events.EventAware):
 
   def executeAbout (self, event):
     parameters = {
-      'appversion'  : VERSION,
-      'ui_driver'   : self._uiinstance.name,
       'name'        : event._form.title or "Unknown",
       'formversion' : event._form.getOption ('version') or "Unknown",
       'author'      : event._form.getOption ('author') or "Unknown",
       'description' : event._form.getOption ('description') or "Unknown",
     }
 
-    if hasattr (self._uiinstance, 'aboutBox'):
-      self._uiinstance.aboutBox (parameters, event._form)
-    else:
-      self.activateForm ('_about', parameters, modal = True)
+    self._uiinstance.showAbout (**parameters)
 
 
   # ---------------------------------------------------------------------------
@@ -1023,15 +989,15 @@ class GFInstance (events.EventAware):
     requested record
     """
 
-    parameters = {'recordnumber': ''}
-    self.activateForm ('_jumpto', parameters, modal = True)
+    fields = [(u_("Recordnumber"), 'record', 'string', None, None, [])]
+    result = self._uiinstance.getInput (u_("Jump to record"), fields)
 
-    if not parameters.has_key ('cancel'):
+    if result is not None:
       if not event._form.endEditing ():
         return
 
       try:
-        count = abs (int (float (parameters ['recordnumber']))) - 1
+        count = abs (int (float (result ['record']))) - 1
 
       except ValueError:
         message = _("Invalid numeric value entered.")
@@ -1216,93 +1182,6 @@ class GFInstance (events.EventAware):
     event._form.refreshDisplay (event._form._currentBlock)
 
 
-  # ---------------------------------------------------------------------------
-  # Execute block-trigger: Pre-Commit
-  # ---------------------------------------------------------------------------
-
-  def preCommit (self, event):
-
-    self._handlePreCommit (event, 'PRE-COMMIT')
-
-
-  # ---------------------------------------------------------------------------
-  # Execute block-trigger: Pre-Insert
-  # ---------------------------------------------------------------------------
-
-  def preInsert (self, event):
-
-    self._handlePreCommit (event, 'PRE-INSERT')
-
-
-  # ---------------------------------------------------------------------------
-  # Execute block-trigger: Pre-Update
-  # ---------------------------------------------------------------------------
-
-  def preUpdate (self, event):
-
-    self._handlePreCommit (event, 'PRE-UPDATE')
-
-
-  # ---------------------------------------------------------------------------
-  # Execute block-trigger: Pre-Delete
-  # ---------------------------------------------------------------------------
-
-  def preDelete (self, event):
-
-    self._handlePreCommit (event, 'PRE-DELETE')
-
-
-  # ---------------------------------------------------------------------------
-  # Execute block-trigger: Pre-Change
-  # ---------------------------------------------------------------------------
-
-  def onRecordTouched (self, event):
-    
-    self._handlePreCommit (event, 'PRE-CHANGE')
-
-
-  # ---------------------------------------------------------------------------
-  # Process a trigger for a given block and all it's fields
-  # ---------------------------------------------------------------------------
-
-  def _handlePreCommit (self, event, trigger):
-
-    try:
-      block = event.record._parent._block
-
-    except AttributeError:
-      return
-
-    saveMode = block.mode
-    block._preCommitWorkingRecord = event.record
-    block.mode = 'precommit'
-    block.processTrigger (trigger)
-
-    for child in block._fieldList:
-      child.processTrigger (trigger)
-
-    block.mode = saveMode
-
-
-  # ---------------------------------------------------------------------------
-  #
-  # ---------------------------------------------------------------------------
-
-  def onQueryNewRecord (self, event):
-
-    try:
-      block = event.record._parent._block
-
-    except AttributeError:
-      return
-
-    # TODO: Running this here causes the trigger to fire prior to all blocks
-    #       being filled
-    #block.processTrigger('POST-QUERY')
-    #for child in block._fieldList:
-    #  child.processTrigger('POST-QUERY')
-
-
   # ---------------------------------------------------------------------------
   # Fire a trigger of the form
   # ---------------------------------------------------------------------------
