@@ -35,10 +35,7 @@ import string, sys
 from gnue.common.apps import errors
 
 
-class InvalidKeystrokeName(StandardError):
-  """
-  Exception class used by the loadUserKeyMap function.
-  """
+class InvalidKeystrokeName (errors.SystemError):
   pass
 
 
@@ -84,8 +81,8 @@ class BaseKeyMapper:
   def loadUserKeyMap(self, dict):
     usermap = {}
 
-    for event in dict.keys():
-      val = string.upper(dict[event])
+    for event in dict.keys ():
+      val = dict [event]
 
       # Save any actual '+' keystrokes
       if val[:1] == '-':
@@ -94,25 +91,28 @@ class BaseKeyMapper:
         val = val[:-2] + 'NEG'
       val = string.replace(string.replace(val,' ',''),'--','-NEG')
 
-      keys = string.split(val,'-')
+      keys = val.split ('-')
 
-      base = None
+      base    = None
       shifted = False
-      meta = False
-      ctrl = False
+      meta    = False
+      ctrl    = False
 
       for key in keys:
-        if key in ('CTRL','CONTROL'):
+        current = key.upper ()
+
+        if current in ('CTRL','CONTROL'):
           ctrl = True
-        elif key in ('META','ALT'):
+        elif current in ('META','ALT'):
           meta = True
-        elif key in ('SHFT','SHIFT'):
+        elif current in ('SHFT','SHIFT'):
           shifted = True
-        elif vk.__dict__.has_key(key):
-          base = vk.__dict__[key]
-        elif len(key) == 1:
-          # TODO: This might not be necessary
-          key = ord(key)
+        elif vk.__dict__.has_key (current):
+          base = vk.__dict__ [current]
+
+        elif len(current) == 1:
+          # We have to use the given key, so Ctrl-r is different than Ctrl-R
+          base = ord (key)
         else:
           raise InvalidKeystrokeName, \
             u_("Invalid keystroke id '%(key)s' in keymap for '%(event)s'") \
@@ -125,7 +125,7 @@ class BaseKeyMapper:
           % {'comb' : dict [event],
              'event': event}
 
-      usermap[(base, shifted, ctrl, meta)] = string.upper(event)
+      usermap [(base, shifted, ctrl, meta)] = event.upper ()
 
 
     # Now, load any default keys they forgot to bind
