@@ -19,11 +19,13 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# $Id: GFBlock.py 7090 2005-03-04 17:47:02Z reinhard $
+# $Id: GFBlock.py 7828 2005-08-12 14:46:55Z reinhard $
 """
 Classes making up the Block object
 """
 
+__revision__ = "$Id: GFBlock.py 7828 2005-08-12 14:46:55Z reinhard $"
+
 from gnue.forms.GFObjects.GFDataSource import GFDataSource
 
 from gnue.common.apps import errors
@@ -31,18 +33,10 @@ from gnue.common.datasources import GConditions
 from GFContainer import GFContainer
 from gnue.common import events
 
-import string
-
-# These should really go somewhere else
-TRUE = 1
-FALSE = 0
-
-
-############################################################
-# GFBlock
-#
-#
 class GFBlock(GFContainer, events.EventAware):
+  """
+  Class that represents the <block> tag in a gfd file.
+  """
   def __init__(self, parent=None):
     GFContainer.__init__(self, parent, 'GFBlock')
 
@@ -73,6 +67,9 @@ class GFBlock(GFContainer, events.EventAware):
     self._fieldMap = {}
     self._fieldList = []
 
+    # True if the block has been saved but the transaction has not yet been
+    # committed. The block will still return True on isPending().
+
     #
     # Trigger exposure
     #
@@ -117,7 +114,9 @@ class GFBlock(GFContainer, events.EventAware):
         'isEmpty':{'function':self.isEmpty,
                     'description':'Returns True if block is empty.'},
         'isSaved':{'function':self.isSaved,
-                    'description':'Returns True if block contains no modified records.'},
+                    'description':'Depriciated: Returns True if block contains no modified records.'},
+        'isPending':{'function':self.isPending,
+                    'description':'Returns True if block contains modified records.'},
         'lastRecord':{'function':self.lastRecord,
                   'description':'Navigates the block to the last record it contains.'},
         'nextRecord':{'function':self.nextRecord,
@@ -190,7 +189,7 @@ class GFBlock(GFContainer, events.EventAware):
       del self.__dict__['restrictInsert']
 
     if hasattr(self,'datasource'):
-      self.datasource = string.lower(self.datasource)
+      self.datasource = self.datasource.lower()
 
     return GFContainer._buildObject(self)
 
@@ -212,6 +211,7 @@ class GFBlock(GFContainer, events.EventAware):
     # Create a stub/non-bound datasource if we aren't bound to one
     if not hasattr(self,'datasource') or not self.datasource:
       ds = GFDataSource(self._form)
+      ds.type = 'unbound'
       self.datasource = ds.name = "__dts_%s" % id(self)
       form._datasourceDictionary[ds.name] = ds
       ds._buildObject()
@@ -224,6 +224,17 @@ class GFBlock(GFContainer, events.EventAware):
           % {'datasource': self.datasource,
              'block': self.name}
 
+    # Register event handling functions
+    self._dataSourceLink.registerEventListeners ({
+        'dsResultSetActivated': self.__dsResultSetActivated,
+        'dsResultSetChanged'  : self.__dsResultSetActivated, # sic!
+        'dsCursorMoved'       : self.__dsCursorMoved,
+        'dsRecordLoaded'      : self.__dsRecordLoaded,
+        'dsRecordTouched'     : self.__dsRecordTouched,
+        'dsCommitInsert'      : self.__dsCommitInsert,
+        'dsCommitUpdate'      : self.__dsCommitUpdate,
+        'dsCommitDelete'      : self.__dsCommitDelete})
+
     # Get min and max child rows, if applicable
     try:
       self._minChildRows = self._dataSourceLink.detailmin
@@ -234,9 +245,6 @@ class GFBlock(GFContainer, events.EventAware):
     except AttributeError:
       self._maxChildRows = None
 
-    # We will monitor our own resultSet changes
-    self._dataSourceLink.registerResultSetListener(self._loadResultSet)
-
     self.walk(self.__setChildRowSettings)
 
   def __setChildRowSettings(self, object):
@@ -250,7 +258,68 @@ class GFBlock(GFContainer, events.EventAware):
     else:
       object._gap = self._gap
 
-  #
+
+  # ---------------------------------------------------------------------------
+  # Event handling functions for datasource events
+  # ---------------------------------------------------------------------------
+
+  def __dsResultSetActivated (self, event):
+    self._resultSet = event.resultSet
+    self._recordCount = self._resultSet.getRecordCount ()
+    recno = self._resultSet.getRecordNumber ()
+    if recno == -1:
+      if not self._resultSet.firstRecord ():
+        self.newRecord ()
+    else:
+      self.switchRecord (recno - self._currentRecord)
+
+  # ---------------------------------------------------------------------------
+
+  def __dsCursorMoved (self, event):
+    # Blocks can't cope with current record #-1
+    recno = self._resultSet.getRecordNumber ()
+    if recno != -1:
+      self.switchRecord (recno - self._currentRecord)
+
+  # ---------------------------------------------------------------------------
+
+  def __dsRecordLoaded (self, event):
+    pass        # TODO: define a trigger for this
+
+  # ---------------------------------------------------------------------------
+
+  def __dsRecordTouched (self, event):
+    # This already gets called by GFField??
+    # self.__fireRecordTrigger ('PRE-CHANGE')
+    pass
+
+  # ---------------------------------------------------------------------------
+
+  def __dsCommitInsert (self, event):
+    self.__fireRecordTrigger ('PRE-INSERT')
+    self.__fireRecordTrigger ('PRE-COMMIT')
+
+  # ---------------------------------------------------------------------------
+
+  def __dsCommitUpdate (self, event):
+    self.__fireRecordTrigger ('PRE-UPDATE')
+    self.__fireRecordTrigger ('PRE-COMMIT')
+
+  # ---------------------------------------------------------------------------
+
+  def __dsCommitDelete (self, event):
+    self.__fireRecordTrigger ('PRE-DELETE')
+    self.__fireRecordTrigger ('PRE-COMMIT')
+
+  # ---------------------------------------------------------------------------
+
+  def __fireRecordTrigger (self, trigger):
+    self.processTrigger (trigger)
+    for field in self._fieldList:
+      field.processTrigger (trigger)
+
+
+  # ---------------------------------------------------------------------------
   #
   #
   def getFocusOrder(self):
@@ -272,7 +341,8 @@ class GFBlock(GFContainer, events.EventAware):
     Returns True if the datasource the block is associated
     with is not pending any changes.
     """
-    # TODO: Find all uses of isSaved() and replace with: not isPending()
+    print "DEPRECIATION WARNING: the use of block.isSaved () is depreciated.", \
+          "Please use block.isPending () instead."
     return not self.isPending()
 
   def isPending(self):
@@ -292,42 +362,6 @@ class GFBlock(GFContainer, events.EventAware):
     """
     self._resultSet.current.delete()
 
-  #
-  #
-  def _loadResultSet(self, resultSet):
-    """
-    Load and process a resultset
-    """
-    self._resultSet = resultSet
-    self._currentRecord = -1
-    self._recordCount = 0
-
-    # This makes the resultSet call our currentRecordMoved method
-    resultSet.registerListener (self)
-
-    # FIXME: Is this used anywhere?
-    resultSet._block = self
-
-    if self._resultSet.firstRecord():
-      # self.switchRecord(0)            # happens via currentRecordMoved
-      self._recordCount = self._resultSet.getRecordCount()
-    else:
-      # This means no results were returned from a query.
-# #       if self._minChildRows:
-# #         # If datasource.detailmin is set, create some blank
-# #         # (but non-empty) records
-# #         while self._recordCount < self._minChildRows:
-# #           self.newRecord()
-# #           # Force the record to no longer be
-# #           field = self._fieldList[0]
-# #           field.setValue(field.getValue())
-# #         self.firstRecord()
-# #       else:
-        # Otherwise, give us a single empty record to work from
-        self.newRecord()
-
-
-
   #
   # isEmpty()
   #
@@ -341,10 +375,6 @@ class GFBlock(GFContainer, events.EventAware):
     return self._resultSet
 
 
-  # This gets called by the resultSet whenever the current record changes
-  def currentRecordMoved (self):
-    self.switchRecord (self._resultSet.getRecordNumber() - self._currentRecord)
-
   #
   #
   #
@@ -357,7 +387,8 @@ class GFBlock(GFContainer, events.EventAware):
       field.gotNewCurrentRecord()
       for entry in field._entryList:
         # This loop is probably better somewhere else
-        entry.recalculateVisible( adjustment, self._currentRecord, self._recordCount)
+        entry.recalculateVisible( adjustment, self._currentRecord, 
+                                  self._recordCount)
       self._form.updateUIEntry(field)
       self._form.refreshUIEvents()
 
@@ -378,15 +409,10 @@ class GFBlock(GFContainer, events.EventAware):
       self._form.commit()
     self.processTrigger('POST-FOCUSOUT')
 
-    if self._resultSet.insertRecord():
-
-      # Set the defaultToLast fields
-      for field, value in self._lastValues.items():
-        if value is not None:
-          self._resultSet.current.setField(field, value, 0)
+    if self._resultSet.insertRecord (self._lastValues):
 
       self._recordCount = self._resultSet.getRecordCount()
-      # self.switchRecord(1)            # happens via currentRecordMoved
+
       # Focus in
       self.processTrigger('PRE-FOCUSIN')
       self.processTrigger('ON-NEWRECORD')
@@ -413,13 +439,13 @@ class GFBlock(GFContainer, events.EventAware):
 
       self._resultSet.nextRecord()
       self._recordCount = self._resultSet.getRecordCount()
-      # self.switchRecord(1)            # happens via currentRecordMoved
 
       # Focus in
       self.processTrigger('PRE-FOCUSIN')
       self.processTrigger('POST-FOCUSIN')
 
-    elif self.autoCreate and not self.isEmpty() and not self.editable in ('update','N'):
+    elif self.autoCreate and not self.isEmpty() and \
+         not self.editable in ('update','N'):
       self.newRecord()
       # Go to first field
       self._form.findAndChangeFocus(self._entryList[0])
@@ -433,8 +459,6 @@ class GFBlock(GFContainer, events.EventAware):
       self.processTrigger('POST-FOCUSOUT')
 
       self._resultSet.lastRecord()
-      # jump = self._resultSet.getRecordNumber () - self._currentRecord
-      # self.switchRecord (jump)        # happens via currentRecordMoved
 
       # Focus in
       self.processTrigger('PRE-FOCUSIN')
@@ -447,7 +471,6 @@ class GFBlock(GFContainer, events.EventAware):
       self.processTrigger('POST-FOCUSOUT')
 
       self._resultSet.firstRecord()
-      # self.switchRecord(0)            # happens via currentRecordMoved
 
       # Focus in
       self.processTrigger('PRE-FOCUSIN')
@@ -461,7 +484,6 @@ class GFBlock(GFContainer, events.EventAware):
       self.processTrigger('POST-FOCUSOUT')
 
       self._resultSet.prevRecord()
-      # self.switchRecord(-1)           # happens via currentRecordMoved
 
       # Focus in
       self.processTrigger('PRE-FOCUSIN')
@@ -472,16 +494,6 @@ class GFBlock(GFContainer, events.EventAware):
           "Please use form.commit () instead."
     self._form.commit ()
 
-    #Commented out (dimas)
-    #Does not work properly anyway
-    #self._form.changeFocus(self)
-    #self._form.commit()
-
-    #TODO: Add error handling
-    #TODO: Check how triggers performed
-    #TODO: original code is in GFForm.commit
-    #self._precommitRecord = self._currentRecord
-    #self.processCommit()
 
   def jumpRecord(self, recordNumber):
     # If recordNumber is negative, move relative to last record
@@ -498,10 +510,6 @@ class GFBlock(GFContainer, events.EventAware):
       if not self._resultSet.setRecord(recordNumber):
         self._resultSet.lastRecord()
 
-      # jump = self._resultSet.getRecordNumber() - self._currentRecord
-      # self._currentRecord = self._resultSet.getRecordNumber()
-      # self.switchRecord(jump)         # happens via currentRecordMoved
-
       # Focus in
       self.processTrigger('PRE-FOCUSIN')
       self.processTrigger('POST-FOCUSIN')
@@ -528,45 +536,27 @@ class GFBlock(GFContainer, events.EventAware):
 
     self._resultSet.setRecord(self._precommitRecord)
 
-    # Step thru all the records looking for records with uncommited 
-    # changes that had default values set.  If one is found then those
-    # fields are reset to their current values *with* modification tracking
-    # on.  The default population on new records is to set the value without
-    # marking the record as modified which prevents their value from being saved.
-    for record in self._resultSet._cachedRecords:
-      if record.isPending():
-        for field in self._lastValues.keys():
-          record.setField(field, record.getField(field), 1)
-
-    # Backstep thru the record adjusting for any prior records that
-    # will be deleted.  Keeps the record postition properly adjusted
-    # during deletes.
-    for record in self._resultSet._cachedRecords:
-      if record.isDeleted():
-        self._resultSet.prevRecord()
-        self._precommitRecord -= 1
-      if record == self._resultSet.current:
-        break
-
-    if not self._dataSourceLink.hasMaster():
-      self._resultSet.post()
-      # The real commit will be done by the form once per connection
-      # self._dataSourceLink._dataObject.commit()
+    if self._getMasterBlock () is None:
+      self._dataSourceLink.postAll ()
 
   #
   # Called after the commit on the backend is through.
   #
   def finalizeCommit (self):
 
+    # Synchronize backend -> resultset -> UI
+    if self._getMasterBlock () is None:
+      self._dataSourceLink.requeryAll (True)
+
     # Our recordCount might have changed if records were deleted
     self._recordCount = self._resultSet.getRecordCount()
 
-    # If all records were deleted, create an empty new one, otherwise make sure
-    # we move the record pointer to the correct record
+    # If all records were deleted, create an empty new one.
     if not self._recordCount:
       self.newRecord()
-    else:
-      self.jumpRecord(self._precommitRecord)
+
+    # The block is not uncommitted any more
+    self.__uncommitted = False
 
     self.mode='normal'
 
@@ -575,15 +565,15 @@ class GFBlock(GFContainer, events.EventAware):
   # processClear
   #
   def processClear(self):
-    self._dataSourceLink._dataObject.rollback()
-    if not self._dataSourceLink.hasMaster():
-      self._dataSourceLink.createEmptyResultSet()
-    else:
-      self._dataSourceLink.createEmptyResultSet(masterRecordSet=self._resultSet._masterRecordSet)
-    self._currentRecord = 0
-    self._recordCount = 0
-    # FIXME: does this happen via currentRecordMoved?
-    self.switchRecord(0)
+
+    # Detail blocks cannot be cleared - they follow their master blindly.
+    if self._getMasterBlock () is not None:
+      return
+
+    if self._dataSourceLink._connection is not None:
+      self._dataSourceLink._connection.rollback ()
+
+    self._dataSourceLink.createEmptyResultSet ()
 
 
   #
@@ -595,25 +585,18 @@ class GFBlock(GFContainer, events.EventAware):
   #
   def processRollback (self, recovering = False, backendRollback = True):
 
+    # Detail blocks cannot be rolled back - they follow their master blindly.
+    if self._getMasterBlock () is not None:
+      return
+
     # if called from GFForm the connection's rollback () has been executed
     # already. But if called from a trigger code we do it here
     if backendRollback:
-      if self._dataSourceLink._dataObject._connection is not None:
-        self._dataSourceLink._dataObject._connection.rollback ()
+      if self._dataSourceLink._connection is not None:
+        self._dataSourceLink._connection.rollback ()
 
     if not recovering:
-      self._currentRecord = 0
-      self._recordCount   = 0
-
-      if not self._dataSourceLink.hasMaster ():
-        self._dataSourceLink.createEmptyResultSet ()
-      else:
-        # if we have a master make sure to keep in touch with it
-        self._dataSourceLink.createEmptyResultSet ( \
-            masterRecordSet = self._resultSet._masterRecordSet)
-
-    # FIXME: does this happen via currentRecordMoved?
-    self.switchRecord (0)
+      self._dataSourceLink.createEmptyResultSet ()
 
 
   #
@@ -626,11 +609,11 @@ class GFBlock(GFContainer, events.EventAware):
     # If Enter-Query is hit thrice, cancel the query and go into normal mode.
 
     if self.mode != 'query':
-        self.mode = 'query'
-        self._query2 = int(gConfigForms("RememberLastQuery"))
-        self._queryValues = {}
-        self._queryValues.update(self._queryDefaults)
-        self.switchRecord(0)
+      self.mode = 'query'
+      self._query2 = int(gConfigForms("RememberLastQuery"))
+      self._queryValues = {}
+      self._queryValues.update(self._queryDefaults)
+      self.switchRecord(0)
 
   def copyQuery(self):
     self._query2 = 0
@@ -645,19 +628,17 @@ class GFBlock(GFContainer, events.EventAware):
   def processQuery(self):
     # Set the maxList to a single master block
     # as a placeholder
-    maxList = [self._dataSourceLink._dataObject]
-    while maxList[0]._masterObject:
-      maxList = [maxList[0]._masterObject]
+    maxList = [self._getTopMasterBlock ()]
 
     # Find the longest master/detail chain that
     # contains query values.  This will become
     # the chain that is queried
     for block in self._logic._blockList:
-      if block._queryValues.keys():
-        templist = [block._dataSourceLink._dataObject]
-        while templist[-1]._masterObject:
-          templist.append(templist[-1]._masterObject)
-        if len(maxList) < len(templist): maxList = templist
+      if block._queryValues.keys ():
+        templist = [block]
+        while (templist [-1])._getMasterBlock ():
+          templist.append ((templist [-1])._getMasterBlock ())
+        if len (maxList) < len (templist): maxList = templist
 
     # Store block states
     for block in self._logic._blockList:
@@ -666,36 +647,35 @@ class GFBlock(GFContainer, events.EventAware):
       block._lastQueryValues.update(block._queryValues)
 
     # graft in the sloppy query stuff if needed
-    for dataobject in maxList:
-      for block in self._logic._blockList:
-        if dataobject == block._dataSourceLink._dataObject:
-          break
+    for block in maxList:
       for entry in block._entryList:
-        if hasattr(entry._field,'sloppyQuery') and block._queryValues.has_key(entry._field):
-          block._queryValues[entry._field] = "%"+ string.join(list(block._queryValues[entry._field]),"%")+"%"
+        if hasattr(entry._field,'sloppyQuery') and \
+           block._queryValues.has_key(entry._field):
+          block._queryValues[entry._field] = "%"+ \
+            "%".join(list(block._queryValues[entry._field]))+"%"
 
-    # Build the sql required by the detail blocks
-    SQL = ""
-    for dataobject in maxList[:-1]:
+    # Find root block
+    rootBlock = maxList [-1]
 
-      for block in self._logic._blockList:
-        if dataobject == block._dataSourceLink._dataObject:
-          break
+    # Condition for the master block
+    conditions = _generateConditional(rootBlock)
+
+    # Conditions for the detail block
+    for block in maxList[:-1]:
 
       block.processTrigger('PRE-QUERY')
       for field in block._fieldList:
         field.processTrigger('PRE-QUERY')
 
-      conditions = _generateConditional(block)
-      SQL = self._dataSourceLink.getQueryString(conditions,1,SQL)
+      c = _generateConditional(block)
+      exist = GConditions.GCexist()
+      exist.table = block._dataSourceLink.table
+      exist.masterlink = block._dataSourceLink.masterlink
+      exist.detaillink = block._dataSourceLink.detaillink
+      exist._children = [c]
+      conditions = GConditions.combineConditions (conditions, exist)
 
-    for block in self._logic._blockList:
-     if maxList[-1] == block._dataSourceLink._dataObject:
-      break
-    rootBlock = block
-
-    conditions = _generateConditional(rootBlock)
-    rootBlock._dataSourceLink.createResultSet(conditions, sql=SQL)
+    rootBlock._dataSourceLink.createResultSet(conditions)
 
     rootBlock._recordCount = rootBlock._resultSet.getRecordCount()
 
@@ -718,8 +698,10 @@ class GFBlock(GFContainer, events.EventAware):
 
   def callFunction (self, name, parameters):
     try:
-      res = self._dataSourceLink.callFuncOfCurrentRecordsetEntry (name,
-                        parameters)
+      self.__uncommitted = True
+      self._dataSourceLink.postAll ()
+      res = self._resultSet.current.call (name, parameters)
+      self._dataSourceLink.requeryAll (False)
     finally:
       self.switchRecord (0)
 
@@ -732,12 +714,45 @@ class GFBlock(GFContainer, events.EventAware):
 
   def updateCurrentRecordSet (self):
     try:
-      self._dataSourceLink.updateCurrentRecordSet ()
-
+      self.__uncommitted = True
+      self._dataSourceLink.postAll ()
+      self._dataSourceLink.requeryAll (False)
     finally:
       self.switchRecord (0)
 
 
+  # ---------------------------------------------------------------------------
+  # Return the top level master block of this block
+  # ---------------------------------------------------------------------------
+
+  def _getTopMasterBlock (self):
+
+    result = self
+    master = result._getMasterBlock ()
+    while master is not None:
+      result = master
+      master = result._getMasterBlock ()
+    return result
+
+
+  # ---------------------------------------------------------------------------
+  # Return the master block of this block
+  # ---------------------------------------------------------------------------
+
+  def _getMasterBlock (self):
+
+    if self._dataSourceLink.hasMaster ():
+      ds = self._dataSourceLink.getMaster ()
+      for block in self._logic._blockList:
+        if block._dataSourceLink == ds:
+          return block
+      # return None in case our master is not bound to a block; e.g. if our
+      # master is a dropdown
+      return None
+    else:
+      return None
+
+
   ###################################################################
   #
   # Trigger settable stuff
@@ -787,62 +802,95 @@ class GFBlock(GFContainer, events.EventAware):
 
 
 
-#
-# _generateConditional
-#
-# Creates a GCondtional tree based upon the values currently
-# stored in the form.
-#
-def _generateConditional(block):
-    conditionLike = {}
-    conditionEq = {}
-    # Get all the user-supplied parameters from the entry widgets
-    for entry, val in block._queryValues.items():
-        if entry._bound and entry.isQueryable() and len(str(val)):
-          if entry.typecast == 'text':
-            if block._convertAsterisksToPercent:
-              try:
-                val = str(val).replace('*','%')
-              except ValueError:
-                pass
-            if (val.find('%') >= 0 or val.find('_') >= 0):
-              conditionLike[entry.field] = val
-            else:
-              conditionEq[entry.field] = val
+# -----------------------------------------------------------------------------
+# Create a condition tree for a given block
+# -----------------------------------------------------------------------------
+
+def _generateConditional (block):
+  """
+  Create a condition tree based upon the values currently stored in the form.
+
+  @param block: GFBlock instance to create a condition for
+  @return: GCondition instance with the condition to use or an empty dictionary
+      if no condition is needed.
+  """
+
+  # 'user input': [GCondition, pass value?]
+  baseComparisons = { '>': ['gt', True],
+                      '>=': ['ge', True],
+                      '<': ['lt', True],
+                      '<=': ['le', True],
+                      '=': ['eq', True],
+                      '!=': ['ne', True],
+                      'like': ['like', True],
+                      'empty': ['null', False],
+                      'notempty': ['notnull', False],
+                    }
+  comparisonDelimeter = ":"
+  
+  condLike = {}
+  condEq   = {}
+  conditions = []
+  # Get all the user-supplied parameters from the entry widgets
+  for entry, val in block._queryValues.items ():
+    if entry._bound and entry.isQueryable () and len (str (val)):
+      
+      # New : operator support
+      match = False
+      for comparison in baseComparisons.keys():
+          
+        if val[:2+len(comparison)].lower() == "%s%s%s" % \
+          (comparisonDelimeter, comparison, comparisonDelimeter):
+          value=val[2+len(comparison):]
+          
+          if baseComparisons[comparison][1]:
+            conditions.append([ baseComparisons[comparison][0], 
+                                ['field', entry.field], 
+                                ['const', value] 
+                              ])
           else:
-            conditionEq[entry.field] = val
+            conditions.append([ baseComparisons[comparison][0], 
+                                ['field', entry.field] 
+                              ])
+          match = True  
+          break
+      
+      # Falls through to old behaviour if no : condition given or 
+      # the : condition is unknown
+      if not match:
+        if entry.typecast == 'text':
+          if block._convertAsterisksToPercent:
+            try:
+              val = str (val).replace ('*', '%')
+            except ValueError:
+              pass
+  
+          if (val.find ('%') >= 0 or val.find ('_') >= 0):
+            condLike [entry.field] = val
+          else:
+            condEq [entry.field] = val
+        else:
+          condEq [entry.field] = val
 
-    if len(conditionLike.keys()) and len(conditionEq.keys()):
-##        GDebug.printMesg(5,'Combining like w/and (%s, %s)' % (conditionLike, conditionEq))
-        conditions = GConditions.combineConditions( \
-            GConditions.buildConditionFromDict(conditionLike, GConditions.GClike), \
-            GConditions.buildConditionFromDict(conditionEq, GConditions.GCeq) )
+  epf = [['eq', ['field', f], ['const', v]] for (f, v) in condEq.items ()]
+  lpf = [['like', ['field', f], ['const', v]] for (f, v) in condLike.items ()]
 
-    elif len(conditionLike.keys()):
-        conditions = GConditions.buildConditionFromDict(conditionLike, GConditions.GClike)
+  if epf or lpf or conditions:
+    result = GConditions.buildConditionFromPrefix (['and'] + epf + 
+                                                   lpf + conditions)
 
-    elif len(conditionEq.keys()):
-        conditions = GConditions.buildConditionFromDict(conditionEq, GConditions.GCeq)
+  else:
+    result = {}
 
-    else:
-        conditions = {}
-
-    return conditions
+  return result
 
 
-
-
-
-# A simple resultset iterator
-# Lets you use ResultSets as:
-#
-#   for record in myResultSet:
-#      blah
-#
-# NOTE: Python 2.2+  (but it won't get called in
-#    Python 2.1 or below, so not a problem)
-#
 class _BlockIter:
+  """A simple resultset iterator that lets you use ResultSets as:
+
+    for record in myResultSet:
+      blah
+  """
   def __init__(self, block):
     self.block = block
     self.new = True
