@@ -217,8 +217,12 @@ class GFField(GFValue):
       for field in [self.fk_key] + self._fk_descr:
         self._fk_datasource.referenceField(field, None)
 
-      # Register as a result set listener
-      self._fk_datasource.registerResultSetListener (self.__loadAllowedValues)
+      # Register event handling functions
+      self._fk_datasource.registerEventListeners ({
+          'dsResultSetActivated': self.__dsResultSetActivated,
+          'dsResultSetChanged'  : self.__dsResultSetActivated, # sic!
+          'dsCursorMoved'       : self.__dsCursorMoved})
+
 
     if hasattr(self, 'queryDefault') and \
          self.queryDefault != None and \
@@ -227,6 +231,26 @@ class GFField(GFValue):
       block._queryDefaults[self] = self.queryDefault
 
 
+  # ---------------------------------------------------------------------------
+  # Event handling functions for datasource events
+  # ---------------------------------------------------------------------------
+
+  def __dsResultSetActivated (self, event):
+    self.__loadAllowedValues (event.resultSet)
+
+  # ---------------------------------------------------------------------------
+
+  def __dsCursorMoved (self, event):
+    # The entry causing the fk record change has already posted a setValue for
+    # this field; our current record already contians the correct data. All we
+    # have to do is tell our UI to update.
+    self._block._form.updateUIEntry (self)
+
+
+  # ---------------------------------------------------------------------------
+  #
+  # ---------------------------------------------------------------------------
+
   def isQueryable(self):
     return self._queryable
 
@@ -250,9 +274,6 @@ class GFField(GFValue):
             value = self._block._queryValues[self]
           except KeyError:
             value = None
-    elif mode == 'precommit':
-        value = self._block._preCommitWorkingRecord.getField(self.field)
-
     else:
       if self._block._resultSet and self._block._resultSet.current:
         value = self._block._resultSet.current.getField(self.field)
@@ -322,9 +343,6 @@ class GFField(GFValue):
     if mode == 'query':
       self._block._queryValues[self] = value
 
-    elif mode == 'precommit':
-      value = self._block._preCommitWorkingRecord.setField(self.field,value)
-
     else:
       self._block.processTrigger('Pre-Change')
       self.processTrigger('Pre-Change')
@@ -419,9 +437,6 @@ class GFField(GFValue):
     # Remember the resultSet for later
     self.__fk_resultSet = resultSet
  
-    # Register as a listener to resultset movements
-    resultSet.registerListener(self)
-
     gDebug (5,'Created for DropDown: %s' % self._allowedValues)
 
   def allowedValues(self):
@@ -441,14 +456,6 @@ class GFField(GFValue):
     pass
 
 
-  # This gets called by the (FK) resultSet whenever the current record changes.
-  # We want the field to follow the selection then.
-  def currentRecordMoved (self):
-    # The entry causing the fk record change has already posted a setValue for
-    # this field; our current record already contians the correct data. All we
-    # have to do is tell our UI to update.
-    self._block._form.updateUIEntry(self)
-
   # This gets called by the block whenever the current record of our own
   # resultset changes. We want the fk resultset to follow.
   def gotNewCurrentRecord (self):
@@ -476,7 +483,7 @@ class GFField(GFValue):
   #
   def triggerAutofillBySequence(self,sequenceName):
     if (not self.getValue()) or self.getValue()=="":
-      sequenceNumber = self._block._dataSourceLink._dataObject.triggerExtensions.getSequence(sequenceName)
+      sequenceNumber = self._block._dataSourceLink._connection.getSequence(sequenceName)
       self.setValue(sequenceNumber)
 
   #
