@@ -39,13 +39,23 @@ from gnue.common.logic.GTrigger import GTriggerExtension
 # Base internal object for GNUE Forms
 #
 class GFObj(GObj, GTriggerExtension):
+  def __repr__(self):
+    try:
+      name = self.name
+    except AttributeError:
+      try: 
+        name = self.id
+      except AttributeError:
+        return '<%s instance at %s>' % (self.__class__, id(self))
+    return '<%s instance (%s) at %s>' % (self.__class__, self.name, id(self))
+    
   def __init__(self, parent=None, type='GFObj'):
     GTriggerExtension.__init__(self)
     GObj.__init__(self, parent, type)
     self.hidden = False
     self.readonly = False
     self._visibleIndex = 0
-    self.name = "__%s__" % self
+    self.name = "__GF%s" % id(self)
     self._rows = 1
     self._gap = 0
     self._inits = []
