@@ -19,7 +19,7 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# $Id: UIdriver.py 7064 2005-02-25 13:55:58Z kilo $
+# $Id: UIdriver.py 7774 2005-08-03 04:23:13Z jcater $
 
 import sys, os, dircache
 
@@ -30,6 +30,7 @@ from gnue.common.utils.FileUtils import dyn_import
 from gnue.common.apps import errors
 
 from gnue.forms.GFForm import *
+from gnue.forms import VERSION
 
 # =============================================================================
 # Exceptions
@@ -125,7 +126,7 @@ class GFUserInterfaceBase (GRootObj, events.EventAware):
                                             # UIForm objects held in memory
     self._formNameToGFForm = {}             # Holds links the to the top level
                                             # UIForm objects held in memory
-    self._gfObjToUIWidget = {}              # dictionary of driver specific 
+    self._gfObjToUIWidget = {}              # dictionary of driver specific
                                             # UIfoo widgets with the GFObj used
                                             # as the key
 
@@ -142,7 +143,7 @@ class GFUserInterfaceBase (GRootObj, events.EventAware):
       basedir = os.path.dirname(sys.modules[moduleName].__file__)
     else:   #Normal case
       basedir  = os.path.dirname (sys.modules [self.__module__].__file__)
-    
+
     uiDriver = os.path.basename (basedir)
     basedir +='/widgets/'
     for widgetName in dircache.listdir (basedir):
@@ -203,6 +204,7 @@ class GFUserInterfaceBase (GRootObj, events.EventAware):
             'beginWAIT'        : self.beginWait,
             'endWAIT'          : self.endWait,
             'formALERT'        : self.formAlert,
+            'formBEEP'         : self.formBeep,
             'uiUPDATESTATUS'   : self.updateStatusBar,
 
             # Clipboard contents
@@ -533,18 +535,122 @@ class GFUserInterfaceBase (GRootObj, events.EventAware):
     else:
       self._showException (group, name, message, detail)
 
+
   # ---------------------------------------------------------------------------
   # Show a message of a given kind
   # ---------------------------------------------------------------------------
 
   def showMessage (self, message, kind = 'Info', title = None, cancel = False):
     """
-    This function calls the UI driver's implementation of the _showMessage
-    method. See _showMessage () for a detailed doc.
+    Show a message box of a given kind and returning a value corresponding with
+    the button pressed to quit the dialog.
+
+    @param message: the text of the message box
+    @param kind: type of the message box. Valid types are: 'Info', 'Warning',
+        'Question', 'Error'
+    @param title: title of the message box
+    @param cancel: If True a cancel button will be added to the dialog
+
+    @return: Depending on the button pressed to quit the message.
+        True : Ok-, Close- or Yes-Button
+        False: No-Button
+        None : Cancel-Button
     """
+
     return self._showMessage (message, kind, title, cancel)
 
 
+  # ---------------------------------------------------------------------------
+
+  def _showMessage (self, message, kind = 'Info', title = None, cancel = False):
+
+    raise ImplementationError, (self.name, '_showMessage')
+
+
+  # ---------------------------------------------------------------------------
+  # Show an about dialog
+  # ---------------------------------------------------------------------------
+
+  def showAbout (self, name = u_("Unknown"), appversion = VERSION,
+      formversion = "?", author = "Unknown", description = "Unknown"):
+    """
+    Displays an about dialog for the current application as defined by the
+    given parameter dictionary.
+
+    @param name: name of the application
+    @param appversion: version of the application (GNUe Forms)
+    @param formversion: version of the form
+    @param author: author of the form
+    @param description: text describing the form
+    """
+
+    self._showAbout (name, appversion, formversion, author, description)
+
+
+  # ---------------------------------------------------------------------------
+
+  def _showAbout (self, name, appversion, formversion, author, description):
+
+    raise ImplementationError, (self.name, '_showAbout')
+
+
+  # ---------------------------------------------------------------------------
+  # Get an input dialog for a given set of fields
+  # ---------------------------------------------------------------------------
+
+  def getInput (self, title, fields, cancel = True):
+    """
+    Prompt the user for a given number of fields and return the result as
+    dictionary.
+
+    @param title: title of the input dialog
+    @param fields: field definition as described below
+    @param cancel: if True the dialog has a cancel button, otherwise not
+
+    These field definitions are specified as follows:
+
+    A field definition is a tuple having these elements:
+    - fieldlabel: This text will be used as label in the left column
+    - fieldname: This is the key in the result-dictionary to contain the value
+        entered by the user
+    - fieldtype: Currently these types are supported:
+        - label: The contents of 'fieldlabel' as static text
+        - warning: The contents of 'fieldlabel' as static text, formatted as
+            warning
+        - string: A text entry control
+        - password: A text entry control with obscured characters
+        - dropdown: Foreach element given in 'elements' a separate ComboBox
+            control will be created, where each one has it's own dictionary of
+            allowed values. If a value is selected in one control, all others
+            are synchronized to represent the same key-value.
+    - default: Default value to use
+    - masterfield: Used for 'dropdowns'. This item specifies another field
+        definition acting as master field. If this master field is changed, the
+        allowedValues of this dropdown will be changed accordingly. If a
+        masterfield is specified the 'allowedValues' dictionaries are built like
+        {master1: {key: value, key: value, ...}, master2: {key: value, ...}}
+    - elements: sequence of input element tuples (label, allowedValues). This
+        is used for dropdowns only. 'label' will be used as ToolTip for the
+        control and 'allowedValues' gives a dictionary with all valid keys to
+        be selected in the dropdown.
+
+    @return: If closed by 'Ok' the result is a dictionary with all values
+      entered by the user, where the "fieldname"s will be used as keys. If the
+      user has not selected a value from a dropdown (i.e. it has no values to
+      select) there will be no such key in the result dictionary. If the dialog
+      is canceled ('Cancel'-Button) the result will be None.
+    """
+
+    return self._getInput (title, fields, cancel)
+
+
+  # ---------------------------------------------------------------------------
+
+  def _getInput (self, title, fields, cancel):
+
+    raise ImplementationError, (self.name, '_getInput')
+
+
   # ---------------------------------------------------------------------------
   # gotoPage
   # ---------------------------------------------------------------------------
@@ -624,7 +730,7 @@ class GFUserInterfaceBase (GRootObj, events.EventAware):
     """
     This function must be overriden by a descendant UI driver class. It get's
     called for all exceptions except UserErrors. It's purpose is to display
-    an exception. 
+    an exception.
     @param group: Group of the exception like 'system', 'admin', 'application'
     @param name: Name of the exception, i.e. 'KeyError', 'FoobarError', ...
     @param message: Message of the exception
@@ -632,22 +738,3 @@ class GFUserInterfaceBase (GRootObj, events.EventAware):
     """
     raise ImplementationError, (self.name, '_showException')
 
-
-  # ---------------------------------------------------------------------------
-  # Implementation of showMessage ()
-  # ---------------------------------------------------------------------------
-  
-  def _showMessage (self, message, kind = 'Info', title = None, cancel = False):
-    """
-    This function must be implemented by a UI driver class and shows a messages
-    of a given kind.
-
-    @param message: the text of the message
-    @param kind: type of the message. Valid types are 'Info', 'Warning',
-        'Question', 'Error'
-    @param title: title of the message
-    @param cancel: If True something like a cancel button should be available
-    @return: True if the Ok-, Close-, or Yes-button was pressed, False if the
-        No-button was pressed or None if the Cancel-button was pressed.
-    """
-    raise ImplementationError, (self.name, '_showMessage')
