@@ -91,7 +91,7 @@ class UIWidget(GObj):
     self._uiForm = self.findParentOfType('UIForm')
 
     try:
-      self._creationEvent.container = self._parent._containerToolkitWidget
+      self._creationEvent.container = self.getParent ()._containerToolkitWidget
     except AttributeError:
 
 
