@@ -89,13 +89,17 @@ class GFUserInterface(GFUserInterfaceBase):
   # Processes the incoming events from other objects
   # From here down should be nothing but eventListeners listed
 
-  #
-  # formAlert
-  #
-  # Rings a bell and alters the statusbar to display
-  # a line of text
-  #
   def formAlert(self, event):
+    """
+    Rings a bell and alters the statusbar to display
+    a line of text
+    """
     self._beep()
     self.statusBar.SetStatusText(event.data,0)
 
+  def formBeep(self, event):
+    """
+    Rings the system bell
+    """
+    self._beep()
+
