@@ -19,7 +19,7 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# $Id: UIdriver.py 6851 2005-01-03 20:59:28Z jcater $
+# $Id: UIdriver.py 7770 2005-08-02 02:43:03Z jamest $
 
 import atexit
 import curses
@@ -29,6 +29,7 @@ from gnue.common.apps import i18n
 from gnue.common.datasources import GLoginHandler
 from gnue.forms.GFKeyMapper import vk, KeyMapper
 from gnue.forms.uidrivers._base.UIdriver import GFUserInterfaceBase
+from gnue.forms.uidrivers.curses import dialogs
 
 # =============================================================================
 # User interface object
@@ -41,10 +42,10 @@ class GFUserInterface (GFUserInterfaceBase):
   # ---------------------------------------------------------------------------
 
   def __init__ (self, eventHandler, name = "Undefined", disableSplash = None,
-                parentContainer = None):
+                parentContainer = None, moduleName = None):
 
     GFUserInterfaceBase.__init__ (self, eventHandler, name, disableSplash,
-                                  parentContainer)
+                                  parentContainer, moduleName)
 
     self.__screen = curses.initscr ()
     atexit.register (curses.endwin)
@@ -75,10 +76,16 @@ class GFUserInterface (GFUserInterfaceBase):
     self.attr ['infomsg']     = curses.color_pair (8) + curses.A_BOLD
     self.attr ['warnmsg']     = curses.color_pair (9) + curses.A_BOLD
     self.attr ['errormsg']    = curses.color_pair (9) + curses.A_BOLD \
-                                                        + curses.A_BLINK
+                                                      + curses.A_BLINK
+    self.attr ['window 1']    = curses.color_pair (5)
 
     self.__currentForm = None
 
+    # TODO: Add a concept of 'lookups' to the GF* layer (like canCOMMIT, ...)
+    #       Meanwhile we're using Ctrl-W (hardcoded)
+    self.lookupKey = 23
+
+
   # ---------------------------------------------------------------------------
   # Initialize user interface
   # ---------------------------------------------------------------------------
@@ -93,6 +100,7 @@ class GFUserInterface (GFUserInterfaceBase):
     self.__exiting = False
 
     KeyMapper.setUIKeyMap (self._keymap)
+    KeyMapper.loadUserKeyMap ({'JUMPPROMPT': 'Ctrl-r'})
 
     # Find out all functions mapped to function keys
                                         # Both hold [eventname, enabled] pairs:
@@ -111,6 +119,7 @@ class GFUserInterface (GFUserInterfaceBase):
         self.registerEventListeners ({'can'    + name: self.__canEvent,
                                       'cannot' + name: self.__cannotEvent})
 
+
   # ---------------------------------------------------------------------------
   # Activate the given form
   # ---------------------------------------------------------------------------
@@ -139,7 +148,8 @@ class GFUserInterface (GFUserInterfaceBase):
     curses.KEY_SIC:    (curses.KEY_IC,    True,  False, False),
     curses.KEY_SDC:    (curses.KEY_DC,    True,  False, False),
     curses.KEY_SHOME:  (curses.KEY_HOME,  True,  False, False),
-    curses.KEY_SEND:   (curses.KEY_END,   True,  False, False)
+    curses.KEY_SEND:   (curses.KEY_END,   True,  False, False),
+    curses.KEY_BTAB:   (9             ,   True,  False, False)
   }
 
   # ---------------------------------------------------------------------------
@@ -191,6 +201,7 @@ class GFUserInterface (GFUserInterfaceBase):
             (key, shift, ctrl, meta) = self.__shiftkeys [key]
           else:
             (shift, ctrl, meta) = (False, False, False)
+
           self._uiFocusWidget._fkeypress (key, shift, ctrl, meta)
       except:
         self.showException ()
@@ -218,6 +229,13 @@ class GFUserInterface (GFUserInterfaceBase):
     # Curses specific
     curses.beep ()
 
+  # ---------------------------------------------------------------------------
+  # Cause console to beep
+  # ---------------------------------------------------------------------------
+
+  def formBeep (self, event):
+    curses.beep ()
+
   # ---------------------------------------------------------------------------
   # Indicate start of nonresponsive phase
   # ---------------------------------------------------------------------------
@@ -293,89 +311,40 @@ class GFUserInterface (GFUserInterfaceBase):
 
   def _showException (self, group, name, message, detail):
 
+    # Give us a chance to debug exceptions until we have a 'good' exception
+    # dialog
+    gDebug (2, "MESSAGE: %s" % message)
+    gDebug (2, "Detail : %s" % detail)
     self.showMessage (message, kind = 'Error')
 
+
   # ---------------------------------------------------------------------------
-  # Ask for login info
+  # Select one of the given options
   # ---------------------------------------------------------------------------
 
-  def askLogin (self, text, fields, error):
+  def getOption (self, title, options):
+    """
+    Create a dialog box for selecting one of the given options
+    @param title: title for the dialog box
+    @param options: dictionary to select a value from
 
-    l = 0
-    for field in fields:
-      if l < len (field [1]):
-        l = len (field [1])
-    w = l + 18
-    if w < len (text):
-      w = len (text)
-    if error and w < len (error):
-      w = len (error)
-    w += 4
+    @return: the selected option (dict-value) or None if cancelled
+    """
 
-    h = len (fields) + 4
-    if error:
-      h += 2
+    if self.__currentForm:
+      (left, top, right, bottom) = self.__currentForm.getCanvas ()
+    else:
+      (right, bottom) = self.__screen.getmaxyx ()
+      left = top = 0
 
-    (screenX, screenY) = self.screenSize ()
+    dialog = dialogs.OptionsDialog (title, options, self.attr, self.lookupKey,
+                                    left, top, right, bottom)
+    try:
+      return dialog.run ()
 
-    win = curses.newwin (h, w, (screenY - h) / 2, (screenX - w) / 2)
-    win.keypad (1)
-    win.bkgd (' ', self.attr ['background'])
-    win.box ()
+    finally:
+      self.__screen.refresh ()
 
-    win.addstr (1, (w - len (text)) / 2, o(text))
-
-    y = 3
-    for field in fields:
-      win.addstr (y, 2, o(field [1]))
-      win.addstr (y, l + 3, ':')
-      win.addstr (y, l + 5, ' ' * 16, self.attr ['entry'])
-      y += 1
-
-    if error:
-      win.addstr (h - 2, (w - len (error)) / 2, o(error))
-
-    result = {}
-
-    y = 3
-    for field in fields:
-      input = ''
-      while True:
-
-        if field [2]:
-          out = '*' * len (input)
-        else:
-          out = input
-        out = out + ' ' * (16 - len (out))
-        win.addstr (y, l + 5, out, self.attr ['focusentry'])
-
-        win.move (y, l + 5 + len (input))
-        k = win.getkey ()
-
-        if k == 'KEY_BACKSPACE':        # backspace
-          if len (input):
-            input = input [:-1]
-          continue
-        elif len (k) > 1:               # ignore other function keys
-          continue
-        elif k == chr (10):             # enter key
-          break
-        elif k == chr (27):             # esc key
-          raise GLoginHandler.UserCanceledLogin
-        elif k < ' ':                   # ignore other control keys
-          continue
-
-        input = input + k
-        if len (input) > 16:
-          input = input [:16]
-
-      win.addstr (y, l + 5, out, self.attr ['entry']) # remove focus color
-      result [field [0]] = input
-      y += 1
-
-    self.__screen.refresh ()            # remove login box
-
-    return result
 
   # ---------------------------------------------------------------------------
   # Clean up everything
@@ -385,6 +354,25 @@ class GFUserInterface (GFUserInterfaceBase):
 
     self.__exiting = True
 
+
+  # ---------------------------------------------------------------------------
+  # Get input data for a given set of fields
+  # ---------------------------------------------------------------------------
+
+  def _getInput (self, title, fields, cancel = True):
+
+    if self.__currentForm:
+      (left, top, right, bottom) = self.__currentForm.getCanvas ()
+    else:
+      (right, bottom) = self.__screen.getmaxyx ()
+      left = top = 0
+
+    dialog = dialogs.InputDialog (title, fields, self.attr, cancel, left, top,
+                                  right, bottom)
+    dialog.run ()
+    return dialog.inputData
+
+
   # ---------------------------------------------------------------------------
   # Helper method for forms to get screen size
   # ---------------------------------------------------------------------------
