@@ -29,6 +29,7 @@
 
 import os.path
 import gtk
+import gobject
 from gnue.common.apps import GConfig
 from gnue.forms import VERSION
 
@@ -42,10 +43,10 @@ class UISplashScreen(gtk.Window):
       bitmapFile=images_dir+gConfigForms('splashScreenPNG')
 
       
-    gtk.Window.__init__(self,gtk.TRUE)
+    gtk.Window.__init__(self, True)
     # not the best, but working decision
     self.connect('destroy', lambda win: self.hide())
-    self.set_resizable(gtk.TRUE)
+    self.set_resizable(True)
     self.resize(525,200)
     self.set_modal(1)
     self.set_position(1) # for center
@@ -86,7 +87,7 @@ class UISplashScreen(gtk.Window):
     #self.CenterOnScreen()
 
   def Show(self):
-    gtk.timeout_add(1500,lambda splash: splash.destroy(),self)
+    gobject.timeout_add(1500,lambda splash: splash.destroy(),self)
     self.show_all()
     self.show_now()
 
