@@ -19,7 +19,7 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# $Id: ToolBar.py 7008 2005-02-11 17:03:06Z reinhard $
+# $Id: ToolBar.py 7226 2005-03-19 18:14:42Z johannes $
 
 import gtk
 
@@ -42,7 +42,7 @@ class ToolBar (Base):
 
     self.toolbar.set_orientation (gtk.ORIENTATION_HORIZONTAL)
     self.toolbar.set_style (gtk.TOOLBAR_ICONS)
-    self.toolbar.set_tooltips (gtk.TRUE)
+    self.toolbar.set_tooltips (True)
     handlebox.add (self.toolbar)
     
     self.container.content_table.attach (handlebox,
