@@ -19,7 +19,7 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# $Id: UIdriver.py 7008 2005-02-11 17:03:06Z reinhard $
+# $Id: UIdriver.py 7551 2005-05-20 08:54:33Z johannes $
 
 import sys
 import string
@@ -34,11 +34,12 @@ try:
   pygtk.require ('2.0')
 
   import gtk
+  import gobject
   import pango
 
   ## check if we really imported gtk 2.0
-  if not hasattr (gtk, "keysyms") or gtk.pygtk_version [1] < 2:
-    print u_("Import error: You need pygtk 2.2 to use the gtk2 user "
+  if not hasattr (gtk, "keysyms") or gtk.pygtk_version [1] < 4:
+    print u_("Import error: You need pygtk 2.4 to use the gtk2 user "
              "interface driver.")
     print u_("You are actually using gtk %s and pygtk %s") \
              % ("%s.%s.%s" % gtk.gtk_version,
@@ -62,7 +63,7 @@ from gnue.forms.uidrivers._commonGuiToolkit import UIdriver as commonToolkit
 from gnue.forms.uidrivers.gtk2.GFApp import *
 from gnue.forms.uidrivers.gtk2.SplashScreen import *
 from gnue.forms.uidrivers.gtk2.widgets._base  import *
-from gnue.forms.uidrivers.gtk2 import about
+from gnue.forms.uidrivers.gtk2 import dialogs
 
 # =============================================================================
 # This class implements a User Interface for GTK2
@@ -114,7 +115,7 @@ class GFUserInterface (commonToolkit.GFUserInterface):
     if not self._disableSplash:
       self.splash = UISplashScreen ()
       self.splash.Show ()
-      gtk.timeout_add (1500, lambda splash: splash.destroy (), self.splash)
+      gobject.timeout_add (1500, lambda splash: splash.destroy (), self.splash)
 
     self.font       = APPFONT
 
@@ -320,10 +321,14 @@ class GFUserInterface (commonToolkit.GFUserInterface):
   # Display an about box
   # ---------------------------------------------------------------------------
 
-  def aboutBox (self, params, form):
-    dialog = about.AboutBox (params, form)
-    dialog.run ()
-    dialog.destroy ()
+  def _showAbout (self, name, appversion, formversion, author, description):
+
+    dlg = dialogs.AboutBox (name, appversion, formversion, author, description)
+    try:
+      dlg.run ()
+
+    finally:
+      dlg.destroy ()
 
 
   # ---------------------------------------------------------------------------
@@ -349,6 +354,21 @@ class GFUserInterface (commonToolkit.GFUserInterface):
       dialog.destroy ()
 
 
+  # ---------------------------------------------------------------------------
+  # Start an input dialog and return the data record or None if cancelled
+  # ---------------------------------------------------------------------------
+
+  def _getInput (self, title, fields, cancel = True):
+
+    dialog = dialogs.InputDialog (title, fields, cancel)
+    try:
+      dialog.run ()
+      return dialog.inputData
+
+    finally:
+      dialog.destroy ()
+
+
   # ---------------------------------------------------------------------------
   # Process all pending events, but do not block if there are no events
   # ---------------------------------------------------------------------------
