@@ -19,7 +19,7 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# $Id: _base.py 7008 2005-02-11 17:03:06Z reinhard $
+# $Id: _base.py 7691 2005-07-07 07:34:35Z johannes $
 
 import gtk
 import types
@@ -147,7 +147,7 @@ class UIHelper (UIWidget):
     if _formRef._currentEntry == gfObject and \
        self.widgets.index (lookupWidget) == gfObject._visibleIndex:
       gDebug (6, "SKIPPING since we already have the focus!")
-      return gtk.FALSE
+      return False
 
     if _formRef._currentEntry != gfObject:
       action = events.Event ('requestFOCUS', gfObject, _form = _formRef)
@@ -159,7 +159,7 @@ class UIHelper (UIWidget):
       action = events.Event ('requestJUMPRECORD', adjust, _form = _formRef)
       self._eventHandler (action)
 
-    return gtk.FALSE
+    return False
 
 
   # ---------------------------------------------------------------------------
@@ -335,6 +335,12 @@ class UIHelper (UIWidget):
         widget.set_cursor (path)
         self._blockHandler (self.selection, '_changedHandler', True)
 
+    elif isinstance (widget, gtk.Label):
+      gfObject = self._uiDriver._WidgetToGFObj [widget]
+      lines = hasattr (gfObject, 'Char__height') and gfObject.Char__height or 1
+
+      widget.set_text ('\n'.join (value.splitlines () [:lines]))
+
     else:
       item = isinstance (widget, gtk.TextView) and widget.get_buffer () or \
           widget
