@@ -19,7 +19,7 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# $Id: entry.py 7008 2005-02-11 17:03:06Z reinhard $
+# $Id: entry.py 7358 2005-04-12 19:44:17Z reinhard $
 
 import gtk
 import math
@@ -255,6 +255,7 @@ class UIEntry (UIHelper):
 
   def setCursorPosition (self, position, index = 0):
     widget = self.widgets [index]
+
     if self.__isCombo (widget):
       entry = isinstance (widget, gtk.Combo) and widget.entry or widget.child
     else:
@@ -278,6 +279,7 @@ class UIEntry (UIHelper):
   # ---------------------------------------------------------------------------
 
   def setSelectedArea (self, selection1, selection2, index = 0):
+
     gDebug (6, "Set Selected Area %s/%s in %s [%s]" % \
         (selection1, selection2, self, index))
 
@@ -410,7 +412,7 @@ class UIEntry (UIHelper):
       else:
         widget.get_toplevel ().child_focus (gtk.DIR_TAB_FORWARD)
 
-      return gtk.TRUE
+      return True
 
     elif event.keyval == gtk.keysyms.Up:
       tBuffer = widget.get_buffer ()
@@ -422,10 +424,10 @@ class UIEntry (UIHelper):
       else:
         widget.get_toplevel ().child_focus (gtk.DIR_TAB_BACKWARD)
 
-      return gtk.TRUE
+      return True
 
     # Key not handled, leave it up to the common handler
-    return gtk.FALSE
+    return False
 
 
   # ---------------------------------------------------------------------------
@@ -448,7 +450,7 @@ class UIEntry (UIHelper):
 
     self._eventHandler (action)
 
-    return gtk.TRUE
+    return True
 
 
   # ---------------------------------------------------------------------------
