@@ -19,7 +19,7 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# $Id: widget.py 6851 2005-01-03 20:59:28Z jcater $
+# $Id: widget.py 7226 2005-03-19 18:14:42Z johannes $
 
 import gtk
 import string
@@ -71,8 +71,8 @@ class UIForm (UIHelper):
     # The main frame of this form
     if self._form.style != 'dialog':
       self.mainWindow = gtk.Window ()
-      self.mainWindow.set_resizable (gtk.TRUE)
-      self.content_table = gtk.Table (4, 1, gtk.FALSE)
+      self.mainWindow.set_resizable (True)
+      self.content_table = gtk.Table (4, 1, False)
       self.mainWindow.add (self.content_table)
 
       self.containerFrame = gtk.Frame ()
@@ -86,10 +86,10 @@ class UIForm (UIHelper):
     else:
       self.mainWindow = gtk.Dialog (flags = gtk.DIALOG_NO_SEPARATOR |
           gtk.DIALOG_DESTROY_WITH_PARENT)
-      self.mainWindow.set_resizable (gtk.TRUE)
+      self.mainWindow.set_resizable (True)
       self.mainWindow.action_area.set_size_request (-1, 0)
 
-      self.content_table = gtk.Table (4, 1, gtk.FALSE)
+      self.content_table = gtk.Table (4, 1, False)
 
       self.containerFrame = gtk.Frame ()
       self.content_table.attach (self.containerFrame,
