@@ -22,7 +22,7 @@
 # UIwxpython.py
 #
 # DESCRIPTION:
-# A wxPython based user interface driver for GNUe forms.
+# A QT based user interface driver for GNUe forms.
 #
 # NOTES:
 #
@@ -57,9 +57,6 @@ class UILoginHandler(GLoginHandler.LoginHandler):
     self.dlg = None
 
   def getLogin(self, loginData, errortext=None):
-    if 1: # TODO: This is left here to prevent me from having to unindent this code
-          # TODO: Since the UI stuff is currently being gutted I'm not wasting the time
-          # TODO: to do the right thing
       if len(loginData[1]):
         loginMesg = _('Login required for\n"%s"') % (loginData[1])
       else:
@@ -198,7 +195,7 @@ class UILoginHandler(GLoginHandler.LoginHandler):
 
       rv = {}
       for i in range(0, len(loginData[2])):
-        rv[loginData[2][i][0]] = self.textctrlList[i].text()
+        rv[loginData[2][i][0]] = unicode(self.textctrlList[i].text())
 
       return rv
 
@@ -226,8 +223,8 @@ class UILoginHandler(GLoginHandler.LoginHandler):
     
     
 class WrappedStaticText(QLabel):
-  def __init__(self, parent, label, width, *args, **params):
-    QLabel.__init__(self, label, parent, *args, **params)
+  def __init__(self, parent, label, width):
+    QLabel.__init__(self, label, parent)
 
 ##    QLabel.setFixedWidth(width)
 
