@@ -124,7 +124,8 @@ class uiBaseEvtHandler:
     elif not (control or alt):
       char = "%s" % event.text()
       if char:
-        action = events.Event('requestKEYPRESS', char, text=char, code=keycode)
+        action = events.Event('requestKEYPRESS',
+                              char, text=char, code=keycode)
 
     if action:
       # Add the object's _form to the outgoing event
@@ -150,9 +151,14 @@ class uiBaseEvtHandler:
     try:
       self.__cursor = self.cursorPosition()
       selected, start, end = self.getSelection()
-      self._eventHandler('requestCURSORMOVE',position=self.cursorPosition(),_form=gfObject._form)
+      self._eventHandler('requestCURSORMOVE',
+                         position=self.cursorPosition(),
+                         _form=gfObject._form)
       if selected:
-        self._eventHandler('requestSELECTWITHMOUSE',position1=start,position2=end,_form=gfObject._form)
+        self._eventHandler('requestSELECTWITHMOUSE',
+                           position1=start,
+                           position2=end,
+                           _form=gfObject._form)
     except AttributeError:
       pass # Not everything has a cursorPosition()
 
@@ -162,7 +168,10 @@ class uiBaseEvtHandler:
     gfObject = uiwidget._gfObject
     selected, start, end = self.getSelection()
     if selected:
-      self._eventHandler('requestSELECTWITHMOUSE',position1=start,position2=end,_form=gfObject._form)
+      self._eventHandler('requestSELECTWITHMOUSE',
+                         position1=start,
+                         position2=end,
+                         _form=gfObject._form)
 
 
 
