@@ -118,7 +118,8 @@ class _SingleLineEdit (_Base, QLineEdit):
   def __init__(self, event, uiwidget):
     QLineEdit.__init__(self, event.container)
     _Base.__init__(self, event, uiwidget, QLineEdit)
-    QObject.connect(self, SIGNAL('selectionChanged()'), self._selectionChanged)
+    QObject.connect(self, SIGNAL('selectionChanged()'),
+                    self._selectionChanged)
 
 
 
@@ -129,7 +130,8 @@ class _MultiLineEdit (_Base, QTextEdit):
   def __init__(self, event, uiwidget):
     QTextEdit.__init__(self, event.container)
     _Base.__init__(self, event, uiwidget, QTextEdit)
-    QObject.connect(self, SIGNAL('selectionChanged()'), self._selectionChanged)
+    QObject.connect(self, SIGNAL('selectionChanged()'),
+                    self._selectionChanged)
 
 
 
@@ -140,7 +142,8 @@ class _ComboBox (_Base, QComboBox):
     QComboBox.__init__(self, True, event.container, "Foo")
     _Base.__init__(self, event, uiwidget, QComboBox)
     QComboBox.setLineEdit(self, _SingleLineEdit(event, uiwidget))
-    QObject.connect(self, SIGNAL('activated(int)'), self.__itemSelected)
+    QObject.connect(self, SIGNAL('activated(int)'),
+                    self.__itemSelected)
 
   def setChoices(self,choices):
     self.__choices = choices
