@@ -189,8 +189,8 @@ class PlainWrapper(ScrollableWrapper):
         p.show()
 
         
-_tabStyles = {'left': 0, ##Top,
-              'right':0, ##Top,
-              'bottom':0, ##Bottom,
-              'top':0, ##Top,
+_tabStyles = {'left': QTabWidget.Top, ##Top,
+              'right': QTabWidget.Top, ##Top,
+              'bottom': QTabWidget.Bottom, ##Bottom,
+              'top':QTabWidget.Top, ##Top,
               }
