@@ -17,7 +17,7 @@
 #
 # Copyright 2000-2005 Free Software Foundation
 #
-# $Id: MenuBar.py 7008 2005-02-11 17:03:06Z reinhard $
+# $Id: MenuBar.py 7657 2005-06-26 11:09:49Z btami $
 #
 # DESCRIPTION:
 # A PyWin32 based user interface driver for GNUe forms.
@@ -25,11 +25,13 @@
 # NOTES:
 #
 
-import string
-import win32api, win32gui, win32ui, win32con, commctrl
+import win32gui
+import win32con
+
+from gnue.common import events
+
 from gnue.forms.uidrivers._commonGuiToolkit.MenuBar import MenuBar as _BaseMenuBar
 from gnue.forms.uidrivers.win32.common import getNextId, textEncode
-from gnue.common import events
 
 _menustyle = win32con.MF_STRING
 
@@ -37,17 +39,16 @@ class MenuBar(_BaseMenuBar):
 
   # Create the menu
   def init(self):
-    self.menu = win32ui.CreateMenu()
-    self._hmnu = self.menu.GetHandle()
+    self.menu = win32gui.CreateMenu()
     return self.menu
 
   # Add a (sub)menu
   def addMenu(self, name, parent):
-    menu = win32ui.CreatePopupMenu()
-    parent.AppendMenu(_menustyle | win32con.MF_POPUP, menu.GetHandle(), textEncode(name))
+    menu = win32gui.CreatePopupMenu()
+    win32gui.AppendMenu(parent, _menustyle | win32con.MF_POPUP, menu, textEncode(name))
     # One would think this would go in init(),
     # but, no... win32 has to be a jerkoff.
-    win32gui.SetMenu(self.container.GetHwnd(), self._hmnu )
+    win32gui.SetMenu(self.container.GetHwnd(), self.menu )
     return menu
 
   # Add a menu item (action)
@@ -69,7 +70,7 @@ class MenuBar(_BaseMenuBar):
 
     id = getNextId()
     self.container.addDescription(id, textEncode(userAction.description) or '')
-    parent.AppendMenu(_menustyle, id, textEncode(label))
+    win32gui.AppendMenu(parent, _menustyle, id, textEncode(label))
     event = 'request' + userAction.event
     self.container.Connect(id, lambda l=self.driver, e=event, f=self.form: l.dispatchEvent(events.Event(e,_form=f)))
 
@@ -78,17 +79,23 @@ class MenuBar(_BaseMenuBar):
 
   # Add a separator
   def addSeparator(self, parent):
-    parent.AppendMenu(win32con.MF_SEPARATOR, 0, "")
+    win32gui.AppendMenu(parent, win32con.MF_SEPARATOR, 0, "")
 
   # Enable a menu item
   def enableItem(self, item):
     parent, id = item
-    parent.EnableMenuItem(id,win32con.MF_BYCOMMAND|win32con.MF_ENABLED)
+    try:
+      win32gui.EnableMenuItem(parent, id, win32con.MF_BYCOMMAND|win32con.MF_ENABLED)
+    except:
+      pass
 
   # Disable a menu item
   def disableItem(self, item):
     parent, id = item
-    parent.EnableMenuItem(id,win32con.MF_BYCOMMAND|win32con.MF_GRAYED)
+    try:
+      win32gui.EnableMenuItem(parent, id, win32con.MF_BYCOMMAND|win32con.MF_GRAYED)
+    except:
+      pass
 
 _cachedIcons = {}
 
