@@ -17,7 +17,7 @@
 #
 # Copyright 2000-2005 Free Software Foundation
 #
-# $Id: ToolBar.py 7008 2005-02-11 17:03:06Z reinhard $
+# $Id: ToolBar.py 7718 2005-07-09 20:48:31Z btami $
 #
 # DESCRIPTION:
 # A PyWin32 based user interface driver for GNUe forms.
@@ -25,13 +25,22 @@
 # NOTES:
 #
 
-import string, sys, struct, os, array
-import win32api, win32gui, win32con, commctrl
-from gnue.forms.uidrivers.win32.widgets._base import Win32Window
-from gnue.forms.uidrivers._commonGuiToolkit.ToolBar import ToolBar as _BaseToolBar
-from gnue.forms.uidrivers.win32.common import getNextId, textEncode
-from gnue.common.apps import GConfig
+import os
+import sys
+import array
+import struct
+
+import win32api
+import win32con
+import win32gui
+import commctrl
+
 from gnue.common import events
+from gnue.common.apps import GConfig
+
+from gnue.forms.uidrivers._commonGuiToolkit.ToolBar import ToolBar as _BaseToolBar
+from gnue.forms.uidrivers.win32.widgets._base import Win32Window
+from gnue.forms.uidrivers.win32.common import getNextId, textEncode
 
 winver = sys.getwindowsversion()
 XP = winver[0]==5 and winver[1]==1 and winver[3]==2
@@ -47,10 +56,6 @@ class ToolBar(_BaseToolBar):
       style, 0, 0, 0, 0,
       self.container, getNextId(), hinst)
 
-#    win32gui.SendMessage(mainToolBar.GetHwnd(), commctrl.TB_BUTTONSTRUCTSIZE, 12, 0)
-#    win32gui.SendMessage(mainToolBar.GetHwnd(), commctrl.TB_SETBITMAPSIZE, 0, (24<<16) + 24) # 24x24
-#    win32gui.SendMessage(mainToolBar.GetHwnd(), commctrl.TB_SETBUTTONSIZE, 0, (24<<16) + 24)  # 24x24
-
     style = win32con.WS_CHILD | win32con.SS_SUNKEN
     Win32Window(self.driver, 0, 'STATIC', '', style, 0, 30, 9999, 2, self.toolbar)
 
@@ -63,8 +68,7 @@ class ToolBar(_BaseToolBar):
         print "*** WARNING: Cannot add 'toolbar-24x24.bmp' to toolbar"
         return
       else:
-        # commctrl.CLR_DEFAULT = 0xFF000000L produces OverflowError...
-        himl = win32gui.ImageList_LoadImage(0, iconloc, 24, 0, 0xFF000000, win32con.IMAGE_BITMAP,
+        himl = win32gui.ImageList_LoadImage(0, iconloc, 24, 0, win32api.RGB(192,192,192), win32con.IMAGE_BITMAP,
           win32con.LR_LOADFROMFILE | win32con.LR_SHARED | win32con.LR_CREATEDIBSECTION)
           
     tbab = struct.pack("ii", 0, himl)
