@@ -1,7 +1,7 @@
 # This file is part of GNU Enterprise.
 #
 # GNU Enterprise is free software; you can redistribute it
-# and/or modify it under the terms of the GNU General Public
+# and/or modify it under the terms of the GNU GPublic
 # License as published by the Free Software Foundation; either
 # version 2, or (at your option) any later version.
 #
@@ -17,7 +17,7 @@
 #
 # Copyright 2000-2005 Free Software Foundation
 #
-# $Id: UIdriver.py 7008 2005-02-11 17:03:06Z reinhard $
+# $Id: UIdriver.py 7659 2005-06-26 16:05:08Z btami $
 #
 # DESCRIPTION:
 # A PyWin32 based user interface driver for GNUe forms.
@@ -28,6 +28,7 @@
 import sys
 import string
 import types
+import math
 
 from gnue.common.apps import i18n
 from gnue.forms.uidrivers._base import Exceptions
@@ -36,6 +37,7 @@ try:
   import win32gui, win32con, afxres, commctrl, win32clipboard, win32ui
 except ImportError:
   raise Exceptions.DriverNotSupported, _("The GNUe-Forms Win32 driver requires PyWin32.")
+from pywin.mfc import window
 
 from gnue.common import events
 from gnue.common.apps import GDebug
@@ -50,6 +52,13 @@ from gnue.forms.uidrivers.win32.GFwin32App import *
 #from gnue.forms.uidrivers.wx.UIWXSplashScreen import *
 from gnue.forms.uidrivers.win32.widgets._base  import *
 from gnue.forms.uidrivers.win32.common import textEncode
+from gnue.forms.uidrivers.win32.dialog import BaseDialog
+from gnue.forms.uidrivers.win32 import dialogs
+
+
+EDIT = 0x0081
+STATIC = 0x0082
+BUTTON = 0x0080
 
 
 def OnWMVScroll(hwnd, msg, wParam, lParam, widget):
@@ -153,7 +162,6 @@ class GFUserInterface(commonToolkit.GFUserInterface):
 #    if not self._disableSplash:
 #      self.splash = UIWXSplashScreen()
 
-
     font_name = gConfigForms('faceName')
     if not font_name:
       # explicite boolean check forces generated report parameter dialog
@@ -166,24 +174,14 @@ class GFUserInterface(commonToolkit.GFUserInterface):
       lf = win32gui.GetObject(win32gui.GetStockObject(fnt))
       font_name = lf.lfFaceName
 
-      #~ print lf.lfHeight, lf.lfWidth, \
-        #~ lf.lfEscapement, lf.lfOrientation, lf.lfWeight, \
-        #~ lf.lfItalic, lf.lfUnderline, lf.lfStrikeOut, lf.lfCharSet, \
-        #~ lf.lfOutPrecision, lf.lfClipPrecision, lf.lfQuality, \
-        #~ lf.lfPitchAndFamily, lf.lfFaceName 
-
-    #~ print 'font_name=',font_name
-    
     font_spec = {'name':font_name, 'height':int(gConfigForms('pointSize'))}
     self._font = win32ui.CreateFont(font_spec)
 
 
-    #
     # Create a dummy window used to compute sizes
-    #
-    from pywin.mfc import window
     dummyWindow = window.Wnd(win32ui.CreateWnd())
     dc = dummyWindow.GetWindowDC()
+
     dc.SelectObject(self._font)
     metrics = dc.GetTextMetrics()
     maxWidth = metrics["tmAveCharWidth"]
@@ -192,17 +190,13 @@ class GFUserInterface(commonToolkit.GFUserInterface):
     maxLeading = metrics["tmExternalLeading"]
 
     self.textWidth    = int(maxWidth+maxLeading)  # The pixel width of text inside a widget
+    self.textWidth    = int(math.ceil(self.textWidth*1.1))
     self.textHeight   = int(maxHeight+maxDescent)  # The pixel height of text inside a widget
-    self.widgetWidth  = self.textWidth            # The pixel width of a 1 char widget (for things like buttons)
+    self.widgetWidth  = self.textWidth             # The pixel width of a 1 char widget (for things like buttons)
     self.widgetHeight = self.textHeight + 5       # The pixel height of a 1 char widget (for things like buttons)
 
-    #
-    # Close dummy window so app doesn't hang when all other windows closed
-    #
-#    dummyWindow.Close()
     dummyWindow.ReleaseDC(dc)
 
-
   #############################################################################
   #
   # Private UIBase support functions
@@ -222,24 +216,23 @@ class GFUserInterface(commonToolkit.GFUserInterface):
       if child._form.name == formName:
         child.mainWindow.Hide()
 
+        if child._form.style == 'dialog':
+          win32gui.PostQuitMessage(0) # Terminate the dialog
+
       exitApp = exitApp and not win32gui.IsWindowVisible(child.mainWindow.GetHwnd())
 
     if exitApp:
       for child in self._children:
         self._win32app._MainWindowList.remove(child.mainWindow)
-        #child.mainWindow.Destroy()
+        child.mainWindow.Destroy()
 
-    if self._form.style == 'dialog':
-      win32gui.PostQuitMessage(0) # Terminate the dialog
-    else:
-      if len(self._win32app._MainWindowList) == 0:
-        win32gui.PostQuitMessage(0) # Terminate the app.
+    if len(self._win32app._MainWindowList) == 0:
+      win32gui.PostQuitMessage(0) # Terminate the app.
 
     for window in self._win32app._MainWindowList:
-      # TODO: needs more work in case we have
-      # TODO: started a dialog from another dialog
-      window.Enable(1)
-
+      if isinstance(window, Win32Window):
+        window.Enable(1)
+        win32gui.SetActiveWindow(window.GetHwnd())
 
   def _beep(self):
     win32gui.MessageBeep(0)
@@ -310,6 +303,7 @@ class GFUserInterface(commonToolkit.GFUserInterface):
     GDebug.printMesg(6, "Getting clipboard value '%s'" % value)
     event.__result__ = value
 
+
   def setClipboardContents(self, event):
     GDebug.printMesg(6,"Setting clipboard '%s'" % event.text)
 
@@ -321,6 +315,7 @@ class GFUserInterface(commonToolkit.GFUserInterface):
     else:
       GDebug.printMesg(6,'Unable to open clipboard for write')
 
+
   def setTitle(self, event):
     ui = self._gfObjToUIWidget[event._form]
     try:
@@ -329,6 +324,10 @@ class GFUserInterface(commonToolkit.GFUserInterface):
       pass
 
 
+  # ---------------------------------------------------------------------------
+  # create a modal message box
+  # ---------------------------------------------------------------------------
+
   def _showMessage (self, message, kind = 'Info', title = None, cancel = False):
     """
     This function creates a message box of a given kind and returns True, False
@@ -362,5 +361,209 @@ class GFUserInterface(commonToolkit.GFUserInterface):
 
     return self._RESPONSE [res]
 
+
+  # ---------------------------------------------------------------------------
+  # Start an input dialog and return the data record or None if cancelled
+  # ---------------------------------------------------------------------------
+
+  def _getInput (self, title, fields, cancel = True):
+
+    dialog = dialogs.InputDialog (title, fields, cancel)
+    dialog.DoModal ()
+    return dialog.inputData
+
+
+  # ---------------------------------------------------------------------------
+  # Show an exception
+  # ---------------------------------------------------------------------------
+
   def _showException (self, group, name, message, detail):
-    self.showMessage (detail, kind = 'Error')
+      
+    dialog = ExceptionDisplay (group, name, message, detail)
+    dialog.DoModal ()
+
+
+  # ---------------------------------------------------------------------------
+  # Display an about box
+  # ---------------------------------------------------------------------------
+
+  def _showAbout (self, name, appversion, formversion, author, description):
+    d = dialogs.AboutBox (name, appversion, formversion, author, description)
+    d.DoModal ()
+
+
+# =============================================================================
+# This class implements a dialog for displaying exceptions
+# =============================================================================
+
+class ExceptionDisplay (BaseDialog):
+
+  _TITLE = {'system'     : _("GNUe Internal System Error"),
+            'admin'      : _("GNUe Unexpected Error"),
+            'application': _("GNUe Application Error")}
+
+  _FORMAT = {
+     'system': u_("An unexpected internal error has occured:\r\n%s.\r\n"
+                  "This means you have found a bug in GNU Enterprise. "
+                  "Please report it to gnue-dev@gnu.org"),
+     'admin': u_("An unexpected error has occured:\r\n%s.\r\n"
+                 "Please contact your system administrator."),
+     'application': u_("An unexpected error has occured:\r\n%s.\r\n"
+                       "Please contact your system administrator.")}
+
+  # ---------------------------------------------------------------------------
+  # Constructor
+  # ---------------------------------------------------------------------------
+
+  def __init__ (self, group, name, message, detail):
+
+    BaseDialog.__init__(self, self._TITLE.get (group, _('Error')), cancel = False, ok = False)
+    self.message_map [win32con.WM_CTLCOLORSTATIC] = self.OnCtlColorStatic
+
+    self.detail = detail.replace('\n','\r\n')
+    
+    cs = win32con.WS_CHILD | win32con.WS_VISIBLE
+    position = (0, 0, 0, 0)
+
+    self.iconID = ID = getNextId()
+    s = cs | win32con.SS_ICON #| win32con.WS_BORDER
+    self.template.append([STATIC, 'icon', ID, (5,8,32,32), s])
+
+    self.messageID = ID = getNextId()
+    s = cs | win32con.SS_LEFT
+    self.template.append([STATIC, textEncode(self._FORMAT.get (group, "%s") % message), \
+                          ID, position, s])
+
+    s = cs | win32con.WS_TABSTOP | win32con.BS_DEFPUSHBUTTON
+    self.template.append([BUTTON, textEncode(u_('Close')), win32con.IDCLOSE, (0, 0, 56, 15), s])
+
+    self.detailsID = ID = getNextId()
+    s = cs | win32con.WS_TABSTOP | win32con.BS_PUSHBUTTON
+    self.template.append([BUTTON, textEncode(u_('>> Details')), ID, (0, 0, 56, 15), s])
+
+    self.detailID = ID = getNextId()
+    s = cs | win32con.ES_MULTILINE | win32con.ES_READONLY | win32con.WS_TABSTOP \
+           | win32con.ES_AUTOVSCROLL #| win32con.WS_VSCROLL
+    es = win32con.WS_EX_STATICEDGE
+    self.template.append([EDIT, textEncode(self.detail), ID, position, s, es])
+
+    self._showsDetail  = False
+
+
+  def OnInitDialog(self, hwnd, msg, wparam, lparam):
+    BaseDialog.OnInitDialog(self, hwnd, msg, wparam, lparam)
+
+    item = win32gui.GetDlgItem(self.hwnd, self.detailID)
+    win32gui.EnableWindow(item, 0)
+
+    ico = win32gui.LoadIcon(0, win32con.IDI_ERROR)
+    bmCtrl = win32gui.GetDlgItem(self.hwnd, self.iconID)
+    win32gui.SendMessage(bmCtrl, win32con.STM_SETICON, ico, 0)
+
+    self.Recalculate()
+
+
+  def OnCommand(self, hwnd, msg, wparam, lparam):
+    id = win32api.LOWORD(wparam)
+    if id == win32con.IDCLOSE:
+      win32gui.EndDialog(hwnd, 1)
+    elif id == self.detailsID:
+      self._showsDetail = not self._showsDetail
+      if self._showsDetail:
+        item = win32gui.GetDlgItem(self.hwnd, self.detailID)
+        win32gui.EnableWindow(item, 1)
+        win32gui.SetDlgItemText(hwnd, id, u_("<< Details"))
+        self.Recalculate()
+      else:
+        item = win32gui.GetDlgItem(self.hwnd, self.detailID)
+        win32gui.EnableWindow(item, 0)
+        win32gui.SetDlgItemText(hwnd, id, u_(">> Details"))
+        self.Recalculate()
+
+  def OnCtlColorStatic(self, hwnd, msg, wparam, lparam):
+    if win32gui.GetDlgCtrlID(lparam) == self.detailID:
+      win32gui.SetBkMode(wparam, win32con.OPAQUE) #TRANSPARENT) #
+      win32gui.SetTextColor(wparam, win32api.RGB(0, 0, 0))
+      return 1
+
+  def Recalculate(self):
+    border = 10
+    
+    dlgWidth = self.Width(self.detailsID) + self.Width(win32con.IDCLOSE) + 20
+    dlgWidth = max(dlgWidth, self.Width(self.messageID))
+    if self._showsDetail:
+      dlgWidth = max(dlgWidth, self.Width(self.detailID))
+
+    ypos = border
+
+    self.SetPosition(self.messageID, border+40, ypos)
+    ypos += self.Height(self.messageID) + 10
+    
+    if self._showsDetail:
+      self.SetPosition(self.detailID, border, ypos)
+      ypos += self.Height(self.detailID) + 10
+    else:
+      dlgItem = win32gui.GetDlgItem(self.hwnd, self.detailID)
+      win32gui.SetWindowPos(dlgItem, 0, 0, 0, 0, 0, 0)
+
+    self.SetPosition(self.detailsID, dlgWidth + 2*border \
+                     - self.Width(self.detailsID) - 8, ypos + 10)
+
+    self.SetPosition(win32con.IDCLOSE, dlgWidth + 2*border \
+                     - self.Width(self.detailsID) \
+                     - self.Width(win32con.IDCLOSE) -15, ypos + 10)
+
+    ypos += self.Height(win32con.IDCLOSE) + border
+    
+    # resize the dialog
+    win32gui.SetWindowPos(self.hwnd, 0,
+                              0, 0,
+                              dlgWidth + 2*border + 10, ypos + 45,
+                              win32con.SWP_NOACTIVATE | win32con.SWP_NOZORDER \
+                              | win32con.SWP_NOMOVE)
+
+    # center the dialog
+    centerWindow(self.hwnd)
+
+
+  def Width(self, id):
+    item = win32gui.GetDlgItem(self.hwnd, id)
+    if id == self.messageID or id == self.detailID:
+      text = win32gui.GetWindowText(item)
+      # GetWindowText has only 512 byte buffer, sigh...
+      if id == self.detailID:
+        text = self.detail
+      if '\r\n' in text:
+        w = max ([win32gui.GetTextExtentPoint32(self.dc, t) [0] for t in text.split ('\r\n')])
+      else:
+        w, h = win32gui.GetTextExtentPoint32(self.dc, text)
+      return w + 40
+    else:
+      l,t,r,b = win32gui.GetWindowRect(item)
+      return r-l
+
+
+  def Height(self, id):
+    item = win32gui.GetDlgItem(self.hwnd, id)
+    if id == self.messageID or id == self.detailID:
+      text = win32gui.GetWindowText(item)
+      if id == self.detailID:
+        text = self.detail
+      if '\r\n' in text:
+        h = sum ([win32gui.GetTextExtentPoint32(self.dc, t) [1] for t in text.split ('\r\n')])
+      else:
+        w, h = win32gui.GetTextExtentPoint32(self.dc, text)
+      if id == self.detailID:
+        h += 2 # extra for WS_EX_STATICEDGE
+      return h
+    else:
+      l,t,r,b = win32gui.GetWindowRect(item)
+      return b-t
+
+
+  def SetPosition(self, id, x, y):
+    item = win32gui.GetDlgItem(self.hwnd, id)
+    win32gui.SetWindowPos(item, 0,
+                          x, y,
+                          self.Width(id), self.Height(id),
+                          win32con.SWP_NOACTIVATE | win32con.SWP_NOZORDER)
