@@ -17,7 +17,7 @@
 #
 # Copyright 2000-2005 Free Software Foundation
 #
-# $Id: _base.py 6963 2005-02-06 12:06:28Z btami $
+# $Id: _base.py 7704 2005-07-07 14:53:02Z johannes $
 #
 # DESCRIPTION:
 # A PyWin32 based user interface driver for GNUe forms.
@@ -25,9 +25,14 @@
 # NOTES:
 #
 
-from types import StringType, UnicodeType
-import win32api, win32gui, win32con, win32ui, commctrl
-import struct, array ,re
+import re
+import struct
+
+import win32ui
+import win32api
+import win32gui
+import win32con
+import commctrl
 
 from gnue.common import events
 
@@ -61,10 +66,10 @@ class Win32Base:
       parent._children.append(self)
 
     self._hwnd = win32gui.CreateWindowEx(styleEx, className, windowTitle, style, x,y, width,height, hparent, menu, instance, None)
-    
+
     # this is only for SetFont
     self._PyCWnd = win32ui.CreateWindowFromHandle(self._hwnd)
-    
+
     self._uiDriver = uidriver
     self._uiDriver._win32app._HwndToTkObj[self._hwnd] = self
 
@@ -89,18 +94,29 @@ class Win32Base:
       elif gfObject.style == 'checkbox':
         uiObject._eventHandler('requestTOGGLECHKBOX',_form=gfObject._form)
       else:
-        cursorPosition = self.getSelectedArea()[1]
-        uiObject._eventHandler('requestCURSORMOVE', position=cursorPosition, _form=gfObject._form)
+        if gfObject._type != 'GFEntry':
+          cursorPosition = self.getSelectedArea()[1]
+          uiObject._request ('CURSORMOVE', position = cursorPosition)
+
         win32gui.CallWindowProc(self._oldWndProc, hwnd, msg, wParam, lParam)
 
     elif msg == win32con.WM_LBUTTONUP:
       gfObject = self._uiDriver._IdToGFObj[self._id]
-      if gfObject._type == 'GFEntry':
-        selection1, selection2 = self.getSelectedArea()
-        if selection1 != selection2:
-          uiObject = self._uiDriver._IdToUIObj[self._id]
-          uiObject._eventHandler('requestSELECTWITHMOUSE', \
-                                           position1=selection1, position2=selection2, _form=gfObject._form)
+      uiObject = self._uiDriver._IdToUIObj[self._id]
+
+      if gfObject._type == 'GFEntry' and gfObject.style == 'default':
+        selection1, selection2 = self.getSelectedArea ()
+        value = self.GetValue ()
+
+        left  = selection1 - value [:selection1].count ('\r')
+        right = selection2 - value [:selection2].count ('\r')
+
+        if left == right:
+          uiObject._request ('CURSORMOVE', position = left)
+
+        else:
+          uiObject._request ('SELECTWITHMOUSE', position1 = left,
+                                                position2 = right)
           
       win32gui.CallWindowProc(self._oldWndProc, hwnd, msg, wParam, lParam)
 
@@ -222,7 +238,11 @@ class Win32Base:
         return win32gui.CallWindowProc(self._oldWndProc, hwnd, msg, wParam, lParam)
 
     elif msg == win32con.WM_PAINT:
-      gfObject = self._uiDriver._IdToGFObj[self._id]
+      try:
+        gfObject = self._uiDriver._IdToGFObj[self._id]
+      except:
+        return win32gui.CallWindowProc(self._oldWndProc, hwnd, msg, wParam, lParam)
+
       if gfObject._type == 'GFImage':
         win32gui.CallWindowProc(self._oldWndProc, hwnd, msg, wParam, lParam)
         hdc = win32gui.GetDC(self._hwnd)
@@ -234,7 +254,7 @@ class Win32Base:
     else:
       return win32gui.CallWindowProc(self._oldWndProc, hwnd, msg, wParam, lParam)
 
-  def SetFont(self,font):
+  def SetFont(self, font):
       self._PyCWnd.SetFont(font,1)
 
   def GetId(self):
@@ -356,7 +376,7 @@ class Win32Entry(Win32Base):
           win32gui.SendMessage(self._hwnd, win32con.LB_SETCURSEL, 0, 0)
       else:
         if hasattr(gfObject,'Char__height') and gfObject.Char__height > 1:
-          corrvalue = re.sub(r'(?<!\r)\n', r'\r\n', value)
+          corrvalue = '\r\n'.join (value.splitlines ())
           win32gui.SetWindowText(self._hwnd, corrvalue)
         else:
           win32gui.SetWindowText(self._hwnd, str(value))
@@ -379,9 +399,22 @@ class Win32Entry(Win32Base):
       return win32gui.GetWindowText(self._hwnd)
 
   def setCursorPosition(self, position):
+    gfObject = self._uiDriver._IdToGFObj[self._id]
+    if gfObject._type == 'GFEntry' and gfObject.style == 'default':
+      value = gfObject.getValue ()
+      if isinstance (value, basestring):
+        part  = value [:position]
+        position = position + part.count ('\n')
     win32gui.SendMessage(self._hwnd, win32con.EM_SETSEL, position, position)
 
   def setSelectedArea(self, selection1, selection2):
+    gfObject = self._uiDriver._IdToGFObj[self._id]
+    if gfObject._type == 'GFEntry' and gfObject.style == 'default':
+      value = gfObject.getValue ()
+      if isinstance (value, basestring):
+        selection1 = selection1 + value [:selection1].count ('\n')
+        selection2 = selection2 + value [:selection2].count ('\n')
+
     win32gui.SendMessage(self._hwnd, win32con.EM_SETSEL, selection1, selection2)
 
   def getSelectedArea(self):
