@@ -17,14 +17,14 @@
 #
 # Copyright 2000-2005 Free Software Foundation
 #
-# $Id: box.py 6851 2005-01-03 20:59:28Z jcater $
+# $Id: box.py 7657 2005-06-26 11:09:49Z btami $
 #
 # DESCRIPTION:
 # A PyWin32 based user interface driver for GNUe forms.
 #
 # NOTES:
 #
-import win32gui, win32con
+import win32con
 
 from gnue.forms.uidrivers.win32.widgets._base import UIHelper, Win32Window
 from gnue.forms.uidrivers.win32.common import *
