@@ -17,7 +17,7 @@
 #
 # Copyright 2000-2005 Free Software Foundation
 #
-# $Id: entry.py 6851 2005-01-03 20:59:28Z jcater $
+# $Id: entry.py 7657 2005-06-26 11:09:49Z btami $
 #
 # DESCRIPTION:
 # A PyWin32 based user interface driver for GNUe forms.
@@ -25,9 +25,10 @@
 # NOTES:
 #
 
-import win32gui, win32con
-from gnue.common import events
+import win32gui
+import win32con
 
+from gnue.common import events
 from gnue.forms.uidrivers.win32.widgets._base import UIHelper, Win32Entry
 from gnue.forms.uidrivers.win32.common import *
 
@@ -70,9 +71,8 @@ class UIEntry(UIHelper):
       
     else: # Normal text box
       height = self.itemHeight + 4
-      width = self.itemWidth + 6
-      style = win32con.WS_CHILD | win32con.ES_NOHIDESEL #| \
-                 #win32con.WS_BORDER #| win32con.ES_AUTOHSCROLL
+      width = self.itemWidth
+      style = win32con.WS_CHILD | win32con.ES_NOHIDESEL #| win32con.WS_BORDER
 
       if hasattr(object,'Char__height') and object.Char__height > 1:
         style = style | win32con.ES_MULTILINE | win32con.ES_AUTOVSCROLL | \
