@@ -17,16 +17,21 @@
 #
 # Copyright 2000-2005 Free Software Foundation
 #
-# $Id: widget.py 6930 2005-02-01 19:21:39Z btami $
+# $Id: widget.py 7657 2005-06-26 11:09:49Z btami $
 #
 # DESCRIPTION:
 # A PyWin32 based user interface driver for GNUe forms.
 #
 # NOTES:
 #
-import string, struct
 
-import win32api, win32gui, win32con, commctrl
+import struct
+
+import win32ui
+import win32api
+import win32gui
+import win32con
+import commctrl
 
 from gnue.forms.uidrivers.win32.common import *
 from gnue.forms.uidrivers.win32.widgets._base import UIHelper, Win32Window
@@ -156,27 +161,28 @@ class UIForm(UIHelper):
       win32gui.SendMessage(self.statusBar.GetHwnd(), commctrl.SB_SETTEXT, 2, textEncode(insertValue))
 
     if currentRecord and  maxRecord:
-      win32gui.SendMessage(self.statusBar.GetHwnd(), commctrl.SB_SETTEXT, 3, string.strip("%s/%s" % (currentRecord,maxRecord)))
+      win32gui.SendMessage(self.statusBar.GetHwnd(), commctrl.SB_SETTEXT, 3, ("%s/%s" % (currentRecord,maxRecord)).strip())
 
     if currentPage and  maxPage:
-      win32gui.SendMessage(self.statusBar.GetHwnd(), commctrl.SB_SETTEXT, 4, string.strip("%s/%s" % (currentPage,maxPage)))
+      win32gui.SendMessage(self.statusBar.GetHwnd(), commctrl.SB_SETTEXT, 4, ("%s/%s" % (currentPage,maxPage)).strip())
 
     return
 
 
   def show(self):
     self.mainWindow.Show()
+    if self._form.style == 'dialog':
+      win32gui.PumpMessages()
 
 
   def showModal(self):
     self.mainWindow.Show()
 
-    for window in self._uiDriver._win32app._MainWindowList:
-      window.Enable(0)
-
     for key in self._uiDriver._formNameToUIForm.keys():
       if self._form.name == key:
         self._uiDriver._formNameToUIForm[key].mainWindow.Enable(1)
-
-    win32gui.PumpMessages()
+      else:
+        self._uiDriver._formNameToUIForm[key].mainWindow.Enable(0)
+    if self._form.style == 'dialog':
+      win32gui.PumpMessages()
 
