@@ -17,7 +17,7 @@
 #
 # Copyright 2000-2005 Free Software Foundation
 #
-# $Id: label.py 6851 2005-01-03 20:59:28Z jcater $
+# $Id: label.py 7657 2005-06-26 11:09:49Z btami $
 #
 # DESCRIPTION:
 # A PyWin32 based user interface driver for GNUe forms.
@@ -25,7 +25,7 @@
 # NOTES:
 #
 
-import win32gui, win32con
+import win32con
 
 from gnue.forms.uidrivers.win32.widgets._base import UIHelper, Win32Window
 from gnue.forms.uidrivers.win32.common import *
@@ -47,7 +47,7 @@ class UILabel(UIHelper):
     if self.itemHeight == -1:
       self.itemHeight = event.widgetHeight
     
-    style = self.alignmentStyle[object.alignment] | win32con.WS_CHILD #| win32con.SS_SUNKEN
+    style = self.alignmentStyle[object.alignment] | win32con.WS_CHILD #| win32con.WS_BORDER
     styleEx = 0
     newWidget = Win32Window(self._uiDriver, styleEx, 'STATIC', textEncode(object.text), style,
                         self.itemX,
