@@ -17,7 +17,7 @@
 #
 # Copyright 2000-2005 Free Software Foundation
 #
-# $Id: scrollbar.py 6851 2005-01-03 20:59:28Z jcater $
+# $Id: scrollbar.py 7657 2005-06-26 11:09:49Z btami $
 #
 # DESCRIPTION:
 # A wxPython based user interface driver for GNUe forms.
@@ -26,8 +26,9 @@
 #
 
 import struct
-import win32gui, win32con
-from gnue.common import events
+
+import win32gui
+import win32con
 
 from gnue.forms.uidrivers.win32.widgets._base import UIHelper, Win32Window
 from gnue.forms.uidrivers.win32.common import getNextId
@@ -42,13 +43,13 @@ class UIScrollBar(UIHelper):
   def _createWidget(self, event, spacer):
     object = event.object
 
-    style = win32con.WS_CHILD | win32con.WS_VISIBLE |win32con.SBS_VERT | win32con.SBS_RIGHTALIGN
+    style = win32con.WS_CHILD | win32con.WS_VISIBLE |win32con.SBS_VERT | win32con.SBS_LEFTALIGN
     styleEx = 0
 
     newWidget = self._widget = Win32Window(self._uiDriver, styleEx, "Scrollbar", "", style,
                         self.itemX,
                         self.itemY, 
-                        -1 , #object.Char__width*event.widgetWidth,
+                        -1, #object.Char__width*event.widgetWidth,
                         object.Char__height*event.widgetHeight,
                         event.container, getNextId())
 
